@@ -25,14 +25,10 @@ OC.L10N.register(
     "Cancel" : "Kanselleer",
     "Add mail account" : "Voeg posrekening toe",
     "Subject" : "Onderwerp",
-    "Sending …" : "Stuur…",
-    "Go back" : "Gaan terug",
-    "Retry" : "Herprobeer",
-    "Message sent!" : "Boodskap gestuur!",
+    "Add link" : "Voeg skakel toe",
     "Send" : "Stuur",
     "Favorite" : "Gunsteling",
     "Select" : "Kies",
-    "Move" : "Skuif",
     "Forward" : "Stuur aan",
     "All day" : "Heeldag",
     "Create" : "Skep",
@@ -44,11 +40,15 @@ OC.L10N.register(
     "Import into calendar" : "Voer in na kalender",
     "Download attachment" : "Laai aanhangsel af",
     "Unnamed" : "Naamloos",
+    "Move" : "Skuif",
     "Quota" : "Kwota",
     "Saving" : "Stoor tans",
     "Remove account" : "Verwyder rekening",
     "Loading …" : "Laai …",
     "New message" : "Nuwe boodskap",
+    "Go back" : "Gaan terug",
+    "Retry" : "Herprobeer",
+    "Sending …" : "Stuur…",
     "Delete" : "Skrap",
     "Add" : "Voeg by",
     "Tags" : "Etikette",
@@ -63,12 +63,16 @@ OC.L10N.register(
     "User" : "Gebruiker",
     "Host" : "Gasheer",
     "Port" : "Poort",
+    "Valid until" : "Geldig tot",
+    "Certificate" : "Sertifikaat",
+    "Back" : "Terug",
+    "Submit" : "Dien in",
     "Keyboard shortcut" : "Snelsleutel",
     "Keyboard shortcuts" : "Sneltoetse",
+    "Archive" : "Argief",
     "Refresh" : "Verfris",
     "Connect your mail account" : "Koppel u posrekening",
     "All" : "Alle",
-    "Archive" : "Argief",
     "Drafts" : "Konsepte",
     "Favorites" : "Gunstelinge",
     "All inboxes" : "Alle inkassies",
