@@ -29,9 +29,10 @@ OC.L10N.register(
     "SMTP Password" : "كلمة مرور SMTP",
     "Save" : "حفظ",
     "Connect" : "اتصال",
-    "Change name" : "تغيير الإسم",
+    "Password required" : "كلمة السر مطلوبة",
     "Signature" : "التوقيع",
     "Mail server" : "خادم البريد",
+    "Change name" : "تغيير الإسم",
     "Email address" : "عنوان البريد الإلكتروني",
     "Cancel" : "إلغاء",
     "Add mail account" : "أضف حساب بريدي",
@@ -40,13 +41,9 @@ OC.L10N.register(
     "Subject" : "الموضوع",
     "Upload attachment" : "رفع المرفقات",
     "Add attachment from Files" : "إضافة مرفقات مِن الملفات",
+    "Add link" : "إضافة رابط",
     "Enter a date" : "ادخل تاريخ",
-    "Sending …" : "جار الإرسال",
-    "Go back" : "العودة",
-    "Retry" : "أعد المحاولة",
-    "Message sent!" : "تم الإرسال الرسالة!",
     "Send" : "أرسل",
-    "No sent mailbox configured. Please pick one in the account settings." : "لم يتم اعداد الرسائل في المرسلة في صندوق البريد. يرجى اختيار واحد في اعدادات الحساب.",
     "Choose a file to add as attachment" : "اختر ملف لإضافته كمرفق",
     "Choose a file to share as a link" : "اختر ملفا لمشاركته كرابط",
     "No messages" : "لاتوجد رسائل",
@@ -56,7 +53,6 @@ OC.L10N.register(
     "Read" : "القراءة",
     "Unselect" : "إلغاء التحديد",
     "Select" : "تحديد",
-    "Move" : "نقل",
     "More actions" : "إجراءات أخرى",
     "Edit as new message" : "تحرير كرسالة جديدة",
     "Create event" : "انشاء فعالية",
@@ -79,6 +75,7 @@ OC.L10N.register(
     "Save all to Files" : "حفظ الجميع لـ الملفات",
     "The images have been blocked to protect your privacy." : "تم حجب هذه الصورة لحماية خصوصيتك",
     "Show images" : "عرض الصور",
+    "Move" : "نقل",
     "Quota" : "الحصة",
     "Saving" : "جاري الحفظ ...",
     "Remove account" : "حذف حساب",
@@ -88,6 +85,10 @@ OC.L10N.register(
     "Clear cache" : "مسح ذاكرة التخزين المؤقتة",
     "Delete mailbox" : "حذف صندوق البريد",
     "New message" : "رسالة جديدة",
+    "Go back" : "العودة",
+    "Retry" : "أعد المحاولة",
+    "Sending …" : "جار الإرسال",
+    "No sent mailbox configured. Please pick one in the account settings." : "لم يتم اعداد الرسائل في المرسلة في صندوق البريد. يرجى اختيار واحد في اعدادات الحساب.",
     "Message" : "الرسالة",
     "Delete" : "حذف",
     "Copy to clipboard" : "نسخ الرابط",
@@ -114,7 +115,11 @@ OC.L10N.register(
     "User" : "المستخدم",
     "Host" : "المضيف",
     "Port" : "المنفذ",
-    "Account connected" : "الحساب متصل",
+    "E-mail address" : "البريد الإلكتروني",
+    "Valid until" : "صالح حتى",
+    "Certificate" : "الشهادة",
+    "Back" : "العودة",
+    "Submit" : "إرسال ",
     "Keyboard shortcuts" : "إختصارات لوحة المفاتيح",
     "Speed up your Mail experience with these quick shortcuts." : "سرّع تجربة بريدك مع هذه الإختصارات.",
     "Compose new message" : "إرسل رسالة جديدة",
@@ -122,10 +127,11 @@ OC.L10N.register(
     "Older message" : "الرسائل الأقدم",
     "Toggle star" : "حدد النجوم",
     "Toggle unread" : "حدد الغير مقروء",
+    "Archive" : "الأرشيف",
     "Refresh" : "تحديث",
+    "Account connected" : "الحساب متصل",
     "Connect your mail account" : "تحديث",
     "All" : "الكل",
-    "Archive" : "الأرشيف",
     "Drafts" : "المسودات",
     "Favorites" : "المفضلات",
     "All inboxes" : "جميع الوارد",
