@@ -13,16 +13,16 @@ OC.L10N.register(
     "SMTP Password" : "Ger-tremen SMTP",
     "Save" : "Enrollañ",
     "Connect" : "Kenstagañ",
+    "Password required" : "Ger-tremen ret",
     "Change name" : "Cheñch env",
     "Cancel" : "Arrest",
-    "Retry" : "Klaskit en dro",
+    "Add link" : "Ouzhpnna ul liamm",
     "Send" : "Kas",
     "Set up an account" : "Staliañ ur c'hont",
     "Unfavorite" : "Digaretañ",
     "Favorite" : "Pennrollañ",
     "Unselect" : "Dizibab",
     "Select" : "Dibab",
-    "Move" : "Diplasañ",
     "Forward" : "War-raok",
     "Create" : "Krouiñ",
     "Comment" : "Displegadenn",
@@ -33,11 +33,13 @@ OC.L10N.register(
     "Reply" : "Respont",
     "Show images" : "Diskouzh ar skeudennoù",
     "Message frame" : "Fram kemenadenn",
+    "Move" : "Diplasañ",
     "Quota" : "Quota",
     "Remove account" : "Lemel ar c'hont",
     "Loading …" : "O Kargañ ...",
     "Edit name" : "Ebmann anv",
     "Clear cache" : "Gwalc'hiñ ar c'hache",
+    "Retry" : "Klaskit en dro",
     "Delete" : "Dilemel",
     "Add" : "Ouzhpennañ",
     "Tags" : "Klavioù",
@@ -53,8 +55,11 @@ OC.L10N.register(
     "User" : "Implijer",
     "Host" : "Ostiz",
     "Port" : "Porzh",
-    "Account connected" : "Kont kenstaged",
+    "Valid until" : "Gwir betek",
+    "Back" : "Distro",
+    "Submit" : "Kinnig",
     "Refresh" : "Freskaat",
+    "Account connected" : "Kont kenstaged",
     "All" : "Pep tra",
     "Favorites" : "Pennrolloù",
     "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr"
