@@ -31,13 +31,14 @@ OC.L10N.register(
     "Connecting" : "Konektante",
     "Save" : "Konservi",
     "Connect" : "Konekti",
+    "Password required" : "Pasvorto bezonata",
     "Account settings" : "Kontaj agordoj",
-    "Change name" : "Ŝanĝi nomon",
     "Signature" : "Subskribo",
     "A signature is added to the text of new messages and replies." : "Subskribo aldonus al la teksto de novaj mesaĝoj kaj respondoj.",
     "Writing mode" : "Skribreĝimo",
     "Preferred writing mode for new messages and replies." : "Prefera skribreĝimo por novaj mesaĝoj kaj respondoj.",
     "Mail server" : "Retpoŝtoservilo",
+    "Change name" : "Ŝanĝi nomon",
     "Email address" : "Retpoŝtadreso",
     "Cancel" : "Nuligi",
     "Add mail account" : "Aldoni retpoŝtan konton",
@@ -56,14 +57,9 @@ OC.L10N.register(
     "Draft saved" : "Malneto konservita",
     "Upload attachment" : "Alŝuti kunsendaĵon",
     "Add attachment from Files" : "Aldoni kunsendaĵojn el „Dosieroj“",
+    "Add link" : "Aldoni ligilon",
     "Enable formatting" : "Ebligi formatado",
     "Enter a date" : "Entajpu daton",
-    "Uploading attachments …" : "Alŝutas kunsendaĵojn...",
-    "Sending …" : "Sendado...",
-    "Error sending your message" : "Eraro dum sendo de via mesaĝo",
-    "Go back" : "Reveni",
-    "Retry" : "Reprovi",
-    "Message sent!" : "Mesaĝo sendiĝis!",
     "Send" : "Sendi",
     "Choose a file to add as attachment" : "Elektu dosieron aldonotan kiel kunsendaĵon",
     "Plain text" : "Ebenaĵa teksto",
@@ -74,7 +70,6 @@ OC.L10N.register(
     "Unselect" : "Malelekti",
     "Select" : "Elekti",
     "Edit tags" : "Redakti etikedojn",
-    "Move" : "Movi",
     "More actions" : "Pliaj agoj",
     "Blind copy recipients only" : "Nur blindkopiaj ricevontoj",
     "Forward" : "Antaŭen",
@@ -100,6 +95,7 @@ OC.L10N.register(
     "Save all to Files" : "Konservi ĉiujn al „Dosieroj“",
     "Choose a folder to store the attachments in" : "Elektu dosierujon en kiu konservi la kunsendaĵojn",
     "The images have been blocked to protect your privacy." : "Bildoj ne montriĝis por protekti vian privatecon.",
+    "Move" : "Movi",
     "Quota" : "Kvoto",
     "Saving" : "Konservado",
     "Move down" : "Movi malsupren",
@@ -109,6 +105,11 @@ OC.L10N.register(
     "Clear cache" : "Forviŝi la kaŝmemoron",
     "_{total} message_::_{total} messages_" : ["{total} mesaĝo","{total} mesaĝoj"],
     "New message" : "Nova mesaĝo",
+    "Error sending your message" : "Eraro dum sendo de via mesaĝo",
+    "Go back" : "Reveni",
+    "Retry" : "Reprovi",
+    "Uploading attachments …" : "Alŝutas kunsendaĵojn...",
+    "Sending …" : "Sendado...",
     "No message selected" : "Neniu mesaĝo elektita",
     "Message" : "Mesaĝo",
     "Delete" : "Forigi",
@@ -149,7 +150,11 @@ OC.L10N.register(
     "Host" : "Gastigo",
     "Port" : "Pordo",
     "SMTP" : "SMTP",
-    "Account connected" : "Konto konektita",
+    "E-mail address" : "Retpoŝtadreso",
+    "Valid until" : "Valida ĝis",
+    "Certificate" : "Atestilo",
+    "Back" : "Antaŭen",
+    "Submit" : "Sendi",
     "Keyboard shortcuts" : "Fulmoklavoj",
     "Speed up your Mail experience with these quick shortcuts." : "Plirapidiĝu per tiuj fulmoklavoj.",
     "Compose new message" : "Krei novan mesaĝon",
@@ -157,10 +162,11 @@ OC.L10N.register(
     "Older message" : "Pli malnova mesaĝo",
     "Toggle star" : "Baskuligi stelon",
     "Toggle unread" : "Baskuligi legostaton",
+    "Archive" : "Arĥivujo",
     "Refresh" : "Aktualigi",
+    "Account connected" : "Konto konektita",
     "Connect your mail account" : "Konekti vian retpoŝtan konton",
     "All" : "Ĉiuj",
-    "Archive" : "Arĥivujo",
     "Drafts" : "Malnetujo",
     "Favorites" : "Pliŝataĵoj",
     "All inboxes" : "Ĉiuj ricevujoj",
