@@ -26,18 +26,14 @@ OC.L10N.register(
     "Signature" : "Allkiri",
     "Cancel" : "Loobu",
     "Subject" : "Teema",
+    "Add link" : "Lisa link",
     "Enter a date" : "Sisesta kuupäev",
-    "Sending …" : "Saadan ...",
-    "Go back" : "Mine tagasi",
-    "Retry" : "Proovi uuesti",
-    "Message sent!" : "Sõnum on saadetud!",
     "Send" : "Saada",
     "Choose a file to add as attachment" : "Vali fail, mida manustada",
     "Favorite" : "Lemmik",
     "Read" : "Lugemine",
     "Select" : "Vali",
     "Edit tags" : "Muuda silte",
-    "Move" : "Liiguta",
     "Forward" : "Edasi",
     "All day" : "Kogu päev",
     "Create" : "Loo",
@@ -49,6 +45,7 @@ OC.L10N.register(
     "Reply" : "Vasta",
     "Unnamed" : "Nimeta",
     "Choose a folder to store the attachment in" : "Vali kaust, kuhu manus salvestada",
+    "Move" : "Liiguta",
     "Quota" : "Kvoot",
     "Saving" : "Salvestamine",
     "Remove account" : "Eemalda konto",
@@ -56,6 +53,9 @@ OC.L10N.register(
     "Edit name" : "Muuda nime",
     "Clear cache" : "Tühjenda puhver",
     "New message" : "Uus sõnum",
+    "Go back" : "Mine tagasi",
+    "Retry" : "Proovi uuesti",
+    "Sending …" : "Saadan ...",
     "Message" : "Sõnum",
     "Delete" : "Kustuta",
     "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
@@ -76,11 +76,14 @@ OC.L10N.register(
     "User" : "Kasutaja",
     "Host" : "Host",
     "Port" : "Port",
+    "Valid until" : "Kehtib kuni",
+    "Certificate" : "Sertifikaat",
+    "Back" : "Tagasi",
     "Keyboard shortcut" : "Klaviatuuri otsetee",
     "Keyboard shortcuts" : "Klaviatuuri otseteed",
+    "Archive" : "Arhiiv",
     "Refresh" : "Värskenda",
     "All" : "Kõik",
-    "Archive" : "Arhiiv",
     "Drafts" : "Mustandid",
     "Favorites" : "Lemmikud",
     "All inboxes" : "Kõik postkastid",
