@@ -31,13 +31,14 @@ OC.L10N.register(
     "SMTP Password" : "رمز عبور SMTP",
     "Save" : "ذخیره",
     "Connect" : "اتصال",
+    "Password required" : "رمز عبور لازم است",
     "Account settings" : "تنظیمات حساب",
-    "Change name" : "تغییر نام",
     "Signature" : "امضا",
     "A signature is added to the text of new messages and replies." : "یک امضا به متن پیامها و پاسخ های جدید اضافه می شود.",
     "Writing mode" : "حالت نوشتن",
     "Preferred writing mode for new messages and replies." : "حالت نوشتن برای پیام ها و پاسخ های جدید ترجیح داده شده است.",
     "Mail server" : "سرور پست الکترونیکی",
+    "Change name" : "تغییر نام",
     "Email address" : "آدرس ایمیل",
     "Cancel" : "لغو",
     "Add mail account" : "حساب کاربری پست الکترونیکی اضافه کنید",
@@ -56,14 +57,9 @@ OC.L10N.register(
     "Draft saved" : "پیش نویس ذخیره شد",
     "Upload attachment" : "پیوست را بارگیری کنید",
     "Add attachment from Files" : "پیوست را از پرونده ها اضافه کنید",
+    "Add link" : "افزودن لینک",
     "Enable formatting" : "قالب بندی را فعال کنید",
     "Enter a date" : "تاریخ را وارد کنید",
-    "Uploading attachments …" : "درحال بارگذاری پیوستها …",
-    "Sending …" : "در حال ارسال ...",
-    "Error sending your message" : "خطایی در ارسال پیام شما",
-    "Go back" : "برگرد",
-    "Retry" : "تلاش دوباره",
-    "Message sent!" : "پیام ارسال شد!",
     "Send" : "ارسال",
     "Choose a file to add as attachment" : "پرونده ای را برای اضافه کردن به عنوان پیوست انتخاب کنید",
     "Plain text" : "متن ساده",
@@ -75,7 +71,6 @@ OC.L10N.register(
     "Unselect" : "لغو انتخاب",
     "Select" : "انتخاب",
     "Edit tags" : "ویرایش تگ ها",
-    "Move" : "انتقال",
     "More actions" : "اقدامات بیشتر",
     "Blind copy recipients only" : "فقط گیرندگان کپی کور",
     "Forward" : "فرستادن",
@@ -102,6 +97,7 @@ OC.L10N.register(
     "Choose a folder to store the attachments in" : "پوشه ای را برای ذخیره کردن پیوست ها انتخاب کنید",
     "The images have been blocked to protect your privacy." : "تصاویر برای محافظت از حریم خصوصی شما مسدود شده اند.",
     "Show images" : "نمایش تصاویر",
+    "Move" : "انتقال",
     "Quota" : "سهم",
     "Saving" : "درحال ذخیره",
     "Move down" : "حرکت به پایین",
@@ -111,6 +107,11 @@ OC.L10N.register(
     "Edit name" : "ویرایش نام",
     "Clear cache" : "پاک‌سازی انباره",
     "New message" : "پیام جدید",
+    "Error sending your message" : "خطایی در ارسال پیام شما",
+    "Go back" : "برگرد",
+    "Retry" : "تلاش دوباره",
+    "Uploading attachments …" : "درحال بارگذاری پیوستها …",
+    "Sending …" : "در حال ارسال ...",
     "No message selected" : "پیامی انتخاب نشده است",
     "Message" : "پیام",
     "Delete" : "حذف",
@@ -157,6 +158,11 @@ OC.L10N.register(
     "Port" : "درگاه",
     "SMTP" : "SMTP",
     "With the settings above, the app will create account settings in the following way:" : "با تنظیمات فوق ، برنامه تنظیمات حساب را به روش زیر ایجاد می کند:",
+    "E-mail address" : "آدرس ایمیل",
+    "Valid until" : "متعبر تا",
+    "Certificate" : "گواهی",
+    "Back" : "بازگشت",
+    "Submit" : "ارسال",
     "Keyboard shortcut" : "صفحه کلید",
     "Keyboard shortcuts" : "میان بر صفحه ی کلید",
     "Speed up your Mail experience with these quick shortcuts." : "تجربه ایمیل خود را با این میانبرهای سریع سرعت بخشید.",
@@ -165,11 +171,11 @@ OC.L10N.register(
     "Older message" : "پیام قدیمی تر",
     "Toggle star" : "تعویض ستاره",
     "Toggle unread" : "تغییر حالت خوانده نشده",
+    "Archive" : "آرشیو",
     "Refresh" : "تازه‌سازی",
     "Connect your mail account" : "حساب ایمیل خود را وصل کنید",
     "Itinerary for {type} is not supported yet" : "برنامه سفر برای {نوع yet هنوز پشتیبانی نمی شود",
     "All" : "همه",
-    "Archive" : "آرشیو",
     "Drafts" : "پیش نویس",
     "Favorites" : "علاقه مندی ها",
     "All inboxes" : "همه صندوق ورودی",
