@@ -12,9 +12,11 @@ OC.L10N.register(
     "Mails" : "Sähköpostit",
     "Mail" : "Sähköposti",
     "💌 A mail app for Nextcloud" : "💌 Sähköpostisovellus Nextcloudille",
+    "Your session has expired. The page will be reloaded." : "Istuntosi on vanhentunut. Sivu ladataan uudelleen.",
     "Drafts are saved in:" : "Luonnokset tallennetaan sijaintiin:",
     "Sent messages are saved in:" : "Lähetetyt viestit tallennetaan sijaintiin:",
     "Deleted messages are moved in:" : "Poistetut viestit tallennetaan sijaintiin:",
+    "Archived messages are moved in:" : "Siirrä arkistoidut viestit:",
     "Auto" : "Automaattinen",
     "Name" : "Nimi",
     "Mail address" : "Sähköpostiosoite",
@@ -37,30 +39,44 @@ OC.L10N.register(
     "SMTP Port" : "SMTP-portti",
     "SMTP User" : "SMTP-käyttäjä",
     "SMTP Password" : "SMTP-salasana",
+    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Google-tilin toiminta tämän sovelluksen kanssa vaatii, että otat kaksivaiheisen todennuksen käyttöön Googlessa ja luot sovelluksen salasanan.",
     "Connecting" : "Yhdistetään",
+    "Reconnect Google account" : "Yhdistä Google-tili uudelleen",
     "Sign in with Google" : "Kirjaudu sisään Google-tililläsi",
     "Save" : "Tallenna",
     "Connect" : "Yhdistä",
+    "Looking up configuration" : "Etsitään määrityksiä",
+    "Password required" : "Salasana vaaditaan",
     "Testing authentication" : "Testataan tunnistautumista",
+    "Awaiting user consent" : "Odotetaan käyttäjän hyväksyntää",
+    "Account created. Please follow the popup instructions to link your Google account" : "Tili luotu. Seuraa ohjeita linkittääksesi Google-tilisi",
+    "Loading account" : "Ladataan tiliä",
+    "Account updated. Please follow the popup instructions to reconnect your Google account" : "Tili päivitetty. Seuraa ohjeita yhdistääksesi Google-tilisi uudelleen",
     "Account updated" : "Tili päivitetty",
     "IMAP server is not reachable" : "IMAP-palvelin ei ole tavoitettavissa",
     "SMTP server is not reachable" : "SMTP-palvelin ei ole tavoitettavissa",
+    "IMAP username or password is wrong" : "IMAP-käyttäjätunnus tai -salasana on väärin",
+    "SMTP username or password is wrong" : "SMTP-käyttäjätunnus tai -salasana on väärin",
     "IMAP connection failed" : "IMAP-yhteys epäonnistui",
     "SMTP connection failed" : "SMTP-yhteys epäonnistui",
+    "Authorization pop-up closed" : "Valtuutusikkuna suljettu",
     "There was an error while setting up your account" : "Tiliä määrittäessä ilmeni virhe",
     "Account settings" : "Tilin asetukset",
-    "Change name" : "Vaihda nimi",
     "Signature" : "Allekirjoitus",
     "A signature is added to the text of new messages and replies." : "Allekirjoitus lisätään uusien viestien ja vastausten tekstiosaan.",
     "Writing mode" : "Kirjoitustila",
     "Preferred writing mode for new messages and replies." : "Ensisijainen kirjoitustila uusissa viesteissä ja vastauksissa.",
     "Default folders" : "Oletuskansiot",
+    "Autoresponder" : "Automaattivastaukset",
     "Sieve filter rules" : "Sieve-filtterin säännöt",
     "Trusted senders" : "Luotetut lähettäjät",
     "Mail server" : "Sähköpostipalvelin",
     "Sieve filter server" : "Sieve-filtteripalvelin",
     "Update alias" : "Päivitä alias",
+    "Select S/MIME certificate" : "Valitse S/MIME-varmenne",
     "Delete alias" : "Poista alias",
+    "{commonName} - Valid until {expiryDate}" : "{commonName} - Kelvollinen {expiryDate} asti",
+    "Change name" : "Vaihda nimi",
     "Email address" : "Sähköpostiosoite",
     "Add alias" : "Lisää alias",
     "Create alias" : "Luo alias",
@@ -69,6 +85,7 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Käytä Gravatar- ja favicon-avatareja",
     "Register as application for mail links" : "Rekisteröi sovellukseksi mail-linkeille",
     "Show keyboard shortcuts" : "Näytä pikanäppäimet",
+    "Manage S/MIME certificates" : "Hallitse S/MIME-varmenteita",
     "Looking for a way to encrypt your emails?" : "Etsitkö tapaa salata sähköpostisi?",
     "Install Mailvelope browser extension here" : "Asenna Mailvelope-selainlaajennus täältä",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Salli sovelluksen kerätä tietoa vuorovaikutuksestasi. Tämän tiedon perusteella sovellus sopeutuu mieltymyksiisi. Nämä tiedot talletetaan vain paikallisesti.",
@@ -94,6 +111,7 @@ OC.L10N.register(
     "Discard & close draft" : "Hylkää ja sulje luonnos",
     "Upload attachment" : "Lähetä liite",
     "Add attachment from Files" : "Lisää liitteitä tiedostosovelluksesta",
+    "Add link" : "Lisää linkki",
     "Send later" : "Lähetä myöhemmin",
     "Enable formatting" : "Käytä muotoilua",
     "Disable formatting" : "Poista muotoilu käytöstä",
@@ -105,25 +123,16 @@ OC.L10N.register(
     "Monday morning" : "Maanantaiaamuna",
     "Custom date and time" : "Omavalintainen päivä ja aika",
     "Enter a date" : "Kirjoita päiväys",
-    "Uploading attachments …" : "Lähetetään liitteitä…",
-    "Sending …" : "Lähetetään…",
-    "Error sending your message" : "Virhe viestiäsi lähettäessä",
-    "Go back" : "Takaisin",
-    "Retry" : "Yritä uudelleen",
-    "Send anyway" : "Lähetä silti",
-    "Message will be sent at" : "Viesti lähetetään",
-    "Message sent!" : "Viesti lähetetty!",
     "Send" : "Lähetä",
-    "Encrypt and send" : "Salaa ja lähetä",
-    "Send unencrypted" : "Lähetä salaamattomana",
     "Message {id} could not be found" : "Viestiä {id} ei löytynyt",
-    "No sent mailbox configured. Please pick one in the account settings." : "Ei postilaatikkoa lähetetyille määritetty. Valitse se tilin asetuksista.",
+    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Mikä tahansa aiempi muotoilu (esimerkiksi lihavointi, kursivointi, alleviivaus tai sisennetyt kuvat) poistetaan.",
     "Turn off formatting" : "Poista muotoilu käytöstä",
     "Turn off and remove formatting" : "Poista käytöstä ja poista muotoilu",
     "Keep formatting" : "Säilytä muotoilu",
     "Choose a file to add as attachment" : "Valitse liitteeksi lisättävä tiedosto",
     "Choose a file to share as a link" : "Valitse tiedosto, joka jaetaan linkkinä",
     "_{count} attachment_::_{count} attachments_" : ["{count} liite","{count} liitettä"],
+    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Liite ylittää sallitun enimmäiskoon {size}. Jaa tiedosto linkin kautta.","Liitteet ylittävät sallitun enimmäiskoon {size}. Jaa tiedostot linkin kautta."],
     "No message found yet" : "Yhtäkään viestiä ei ole vielä löytynyt",
     "Set up an account" : "Määritä tili",
     "Plain text" : "Raakateksti",
@@ -131,6 +140,7 @@ OC.L10N.register(
     "No messages in this mailbox" : "Ei viestejä tässä postilaatikossa",
     "No messages" : "Ei viestejä",
     "Draft: " : "Luonnos: ",
+    "Encrypted message" : "Salattu viesti",
     "This message is unread" : "Tämä viesti on lukematon",
     "Unfavorite" : "Poista suosikeista",
     "Favorite" : "Suosikki",
@@ -142,7 +152,6 @@ OC.L10N.register(
     "Unselect" : "Poista valinta",
     "Select" : "Valitse",
     "Edit tags" : "Muokkaa tunnisteita",
-    "Move" : "Siirrä",
     "Move thread" : "Siirrä ketju",
     "Archive thread" : "Arkistoi ketju",
     "Delete thread" : "Poista ketju",
@@ -166,15 +175,22 @@ OC.L10N.register(
     "Event created" : "Tapahtuma luotu",
     "Could not create event" : "Tapahtumaa ei voitu luoda",
     "You accepted this invitation" : "Hyväksyit tämän kutsun",
+    "You tentatively accepted this invitation" : "Hyväksyit tämän kutsun alustavasti",
+    "You declined this invitation" : "Kieltäydyit tästä kutsusta",
+    "You already reacted to this invitation" : "Reagoit jo tähän kutsuun",
     "You have been invited to an event" : "Sinut on kutsuttu tapahtumaan",
     "This event was cancelled" : "Tämä tapahtuma peruttiin",
     "Comment" : "Kommentti",
     "Accept" : "Hyväksy",
     "Decline" : "Kieltäydy",
+    "Tentatively accept" : "Alustavasti hyväksytty",
     "More options" : "Lisää valintoja",
     "This event is in the past." : "Tämä tapahtuma on menneisyydessä.",
     "This event was updated" : "Tämä tapahtuma päivitettiin",
     "{attendeeName} accepted your invitation" : "{attendeeName} hyväksyi kutsusi",
+    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} hyväksyi kutsusi alustavasti",
+    "{attendeeName} declined your invitation" : "{attendeeName} kieltäytyi kutsustasi",
+    "{attendeeName} reacted to your invitation" : "{attendeeName} reagoi kutsuusi",
     "Could not open mailbox" : "Postilaatikkoa ei voitu avata",
     "Loading messages …" : "Ladataan viestejä …",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Viestejäsi indeksoidaan. Tämä saattaa kestää hetken varsinkin suurikokoisissa postilaatikoissa.",
@@ -199,9 +215,11 @@ OC.L10N.register(
     "Unnamed" : "Nimetön",
     "Embedded message" : "Upotettu viesti",
     "Choose a folder to store the attachment in" : "Valitse kansio liitetiedoston tallentamiselle",
+    "View fewer attachments" : "Näytä vähemmän liitteitä",
     "Save all to Files" : "Tallenna kaikki tiedostoihin",
     "Download Zip" : "Lataa Zip",
     "Choose a folder to store the attachments in" : "Valitse kansio johon liitteet tallennetaan",
+    "_View {count} more attachment_::_View {count} more attachments_" : ["Näytä {count} liite lisää","Näytä {count} liitettä lisää"],
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Tämä viesti on salattu PGP:llä. Asenna Mailvelope purkaaksesi viestin salauksen.",
     "The images have been blocked to protect your privacy." : "Kuvat estettiin yksityisyytesi suojelemiseksi.",
     "Show images" : "Näytä kuvat",
@@ -210,6 +228,7 @@ OC.L10N.register(
     "Always show images from {domain}" : "Näytä aina kuvat verkkotunnuksesta {domain}",
     "Message frame" : "Viestiruutu",
     "Quoted text" : "Lainattu teksti",
+    "Move" : "Siirrä",
     "Moving" : "Siirretään",
     "Moving thread" : "Siirretään ketjua",
     "Moving message" : "Siirretään viestiä",
@@ -248,26 +267,44 @@ OC.L10N.register(
     "_{total} message_::_{total} messages_" : ["{total} viesti","{total} viestiä"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} lukematonta {total} viestistä","{unread} lukematonta {total} viestistä"],
     "New message" : "Uusi viesti",
+    "Error sending your message" : "Virhe viestiäsi lähettäessä",
+    "Go back" : "Takaisin",
+    "Retry" : "Yritä uudelleen",
+    "Uploading attachments …" : "Lähetetään liitteitä…",
+    "Sending …" : "Lähetetään…",
+    "Warning sending your message" : "Varoitus viestiä lähettäessä",
+    "Send anyway" : "Lähetä silti",
     "Edit message" : "Muokkaa viestiä",
     "Draft" : "Luonnos",
+    "No sent mailbox configured. Please pick one in the account settings." : "Ei postilaatikkoa lähetetyille määritetty. Valitse se tilin asetuksista.",
     "Message discarded" : "Viesti hylätty",
     "Could not discard message" : "Viestiä ei voitu hylätä",
     "No message selected" : "Viestiä ei ole valittu",
+    "Autoresponder off" : "Automaattivastaukset pois päältä",
+    "Autoresponder on" : "Automaattivastaukset päällä",
     "First day" : "Ensimmäinen päivä",
     "Last day (optional)" : "Viimeinen päivä (valinnainen)",
     "Message" : "Viesti",
     "Oh Snap!" : "Oho!",
+    "Save autoresponder" : "Tallenna automaattivastaus",
     "Pending or not sent messages will show up here" : "Odottavat tai vielä lähettämättömät viestit näkyvät täällä",
     "Delete" : "Poista",
     "Message could not be sent" : "Viestiä ei voitu lähettää",
     "Message deleted" : "Viesti poistettu",
+    "Contacts with this address" : "Yhteystiedot tällä osoitteella",
     "Add to Contact" : "Lisää yhteystietoon",
     "New Contact" : "Uusi yhteystieto",
     "Copy to clipboard" : "Kopioi leikepöydälle",
     "Contact name …" : "Yhteystiedon nimi…",
     "Add" : "Lisää",
+    "Copied email address to clipboard" : "Sähköpostiosoite kopioitu leikepöydälle",
+    "Could not copy email address to clipboard" : "Sähköpostiosoitetta ei voitu kopioida leikepöydälle",
+    "Pick a start date" : "Valitse aloituspäivä",
+    "Pick an end date" : "Valitse päättymispäivä",
     "Select sender" : "Valitse lähettäjä",
     "Select recipient" : "Valitse vastaanottaja",
+    "Select cc recipient" : "Valitse kopion vastaanottaja",
+    "Select bcc recipient" : "Valitse piilokopion vastaanottaja",
     "Tags" : "Tunnisteet",
     "Select tags" : "Valitse tunnisteet",
     "Has attachments" : "On liitteitä",
@@ -277,11 +314,16 @@ OC.L10N.register(
     "Disabled" : "Pois käytöstä",
     "Enabled" : "Käytössä",
     "Sieve Host" : "Sieve-palvelin",
+    "Sieve Security" : "Sieve-tietoturva",
+    "Sieve Port" : "Sieve-portti",
+    "Sieve Credentials" : "Sieve-kirjautumistiedot",
     "IMAP Credentials" : "IMAP-kirjautumistiedot",
     "Custom" : "Omavalintainen",
     "Sieve User" : "Sieve-käyttäjä",
     "Sieve Password" : "Sieve-salasana",
+    "Save sieve settings" : "Tallenna sieve-asetukset",
     "Signature …" : "Allekirjoitus…",
+    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Allekirjoituksesi koko on yli kaksi megatavua. Tämä saattaa vaikuttaa muokkaimen suorituskykyyn.",
     "Save signature" : "Tallenna allekirjoitus",
     "Place signature above quoted text" : "Aseta allekirjoitus lainatun tekstin yläpuolelle",
     "Add default tags" : "Lisää oletustunnisteet",
@@ -291,9 +333,14 @@ OC.L10N.register(
     "Unset" : "Poista",
     "Add tag" : "Lisää tunniste",
     "Saving tag …" : "Tallennetaan tunnistetta…",
+    "Tag name is a hidden system tag" : "Tunnisteen nimi on piilotettu järjestelmätunniste",
     "Tag already exists" : "Tunniste on jo olemassa",
+    "An error occurred, unable to create the tag." : "Tapahtui virhe, tunnistetta ei voitu luoda.",
+    "An error occurred, unable to rename the tag." : "Tapahtui virhe, tunnistetta ei voitu nimetä uudelleen.",
+    "Loading thread" : "Ladataan ketjua",
     "Not found" : "Ei löytynyt",
     "Could not load your message thread" : "Viestiketjua ei voitu ladata",
+    "The thread doesn't exist or has been deleted" : "Ketjua ei ole olemassa tai se on poistettu",
     "Mark as favorite" : "Merkitse suosikiksi",
     "Mark as unread" : "Merkitse lukemattomaksi",
     "Mark as read" : "Merkitse luetuksi",
@@ -321,11 +368,21 @@ OC.L10N.register(
     "Add new config" : "Lisää uusi asetus",
     "Provision all accounts" : "Provisioidaan kaikki käyttäjät",
     "Anti Spam Service" : "Roskapostin estopalvelu",
+    "Gmail integration" : "Gmail-integraatio",
+    "Microsoft integration" : "Microsoft-integraatio",
+    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft sallii käyttäjien yhdistää sähköpostiin IMAP:ia käyttäen. Tietoturvasyistä tällainen käyttö on mahdollista vain OAuth 2.0 -yhteydellä.",
+    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Rekisteröi uusi sovellus Microsoft Azure Active Directory -portaalissa. Lisää URL-osoite {url} uudelleenohjauksen URI:ksi.",
     "Anti Spam" : "Roskapostin esto",
     "The original message will be attached as a \"message/rfc822\" attachment." : "Alkuperäinen viesti asetetaan \"message/rfc822\"-liitteeksi.",
     "Reset" : "Palauta",
     "Client ID" : "Asiakas-ID",
     "Client secret" : "Asiakassalasana",
+    "Unlink" : "Poista linkitys",
+    "Google integration configured" : "Google-integraatio määritetty",
+    "Could not configure Google integration" : "Google-integraatiota ei voitu määrittää",
+    "Google integration unlinked" : "Google-integraation linkitys poistettu",
+    "Microsoft integration configured" : "Microsoft-integraatio määritetty",
+    "Could not configure Microsoft integration" : "Microsoft-integraatiota ei voitu määrittää",
     "Email: {email}" : "Sähköposti: {email}",
     "General" : "Yleiset",
     "IMAP" : "IMAP",
@@ -338,7 +395,18 @@ OC.L10N.register(
     "Enable LDAP aliases integration" : "Käytä LDAP-aliasten integraatiota",
     "Save Config" : "Tallenna asetus",
     "With the settings above, the app will create account settings in the following way:" : "Sovellus luo tiliasetukset yllä olevin asetuksin seuraavasti:",
-    "Account connected" : "Tili yhdistetty",
+    "S/MIME certificates" : "S/MIME-varmenteet",
+    "Certificate name" : "Varmenteen nimi",
+    "E-mail address" : "Sähköpostiosoite",
+    "Valid until" : "Kelvollinen",
+    "Import certificate" : "Tuo varmenne",
+    "Import S/MIME certificate" : "Tuo S/MIME-varmenne",
+    "Certificate" : "Varmenne",
+    "Back" : "Takaisin",
+    "Submit" : "Lähetä",
+    "Certificate imported successfully" : "Varmenne tuotu onnistuneesti",
+    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Varmenteen tuonti epäonnistui. Varmista, että yksityinen avain vastaa varmennetta ja ettei se ole suojattu tunnuslauseella.",
+    "Failed to import the certificate" : "Varmenteen tuominen epäonnistui",
     "Keyboard shortcut" : "Näppäimistön pikanäppäin",
     "Keyboard shortcuts" : "Pikanäppäimet",
     "Speed up your Mail experience with these quick shortcuts." : "Nopeuta sähköpostikokemustasi näillä pikanäppäimillä.",
@@ -347,11 +415,13 @@ OC.L10N.register(
     "Older message" : "Vanhempi viesti",
     "Toggle star" : "Lisää/poista tähti",
     "Toggle unread" : "Merkitse luetuksi/lukemattomaksi",
+    "Archive" : "Arkisto",
     "Refresh" : "Päivitä",
+    "Account connected" : "Tili yhdistetty",
+    "You can close this window" : "Voit sulkea tämän ikkunan",
     "Connect your mail account" : "Yhdistä sähköpostitilisi",
     "To add a mail account, please contact your administrator." : "Ole yhteydessä ylläpitoon lisätäksesi sähköpostitilin.",
     "All" : "Kaikki",
-    "Archive" : "Arkisto",
     "Drafts" : "Luonnokset",
     "Favorites" : "Suosikit",
     "Priority inbox" : "Tärkeät saapuneet",
@@ -360,6 +430,7 @@ OC.L10N.register(
     "Junk" : "Roskaposti",
     "Sent" : "Lähetetyt",
     "Trash" : "Roskakori",
+    "Connect OAUTH2 account" : "Yhdistä OAUTH2-tili",
     "Error while sharing file" : "Virhe tiedostoa jakaessa",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n uusi viesti \nlähettäjältä {from}","%n uutta viestiä \nlähettäjältä {from}"],
