@@ -38,8 +38,8 @@ OC.L10N.register(
     "Connecting" : "מתבצע חיבור",
     "Save" : "שמור",
     "Connect" : "התחברות",
+    "Password required" : "נדרשת ססמה",
     "Account settings" : "הגדרות חשבון",
-    "Change name" : "החלפת שם",
     "Signature" : "חתימה",
     "A signature is added to the text of new messages and replies." : "נוספה חתימה לטקסט של הודעות חדשות ותגובות.",
     "Writing mode" : "מצב כתיבה",
@@ -47,6 +47,7 @@ OC.L10N.register(
     "Default folders" : "תיקיות בררת מחדל",
     "Trusted senders" : "שולחים מהימנים",
     "Mail server" : "שרת דוא״ל",
+    "Change name" : "החלפת שם",
     "Email address" : "כתובת דוא״ל",
     "Add alias" : "הוספת כינוי",
     "Cancel" : "ביטול",
@@ -71,20 +72,13 @@ OC.L10N.register(
     "Draft saved" : "הטיוטה נשמרה",
     "Upload attachment" : "העלאת קובץ מצורף",
     "Add attachment from Files" : "הוספת קובץ מצורף מהקבצים",
+    "Add link" : "הוספת קישור",
     "Enable formatting" : "הפעלת עיצוב",
     "Request a read receipt" : "בקשת אישור קריאה",
     "Encrypt message with Mailvelope" : "הצפנת הודעה עם Mailvelope",
     "Enter a date" : "נא למלא תאריך",
-    "Uploading attachments …" : "הקבצים המצורפים מועלים…",
-    "Sending …" : "שולח...",
-    "Error sending your message" : "שליחת ההודעה שלך נכשלה",
-    "Go back" : "חזרה",
-    "Retry" : "ניסיון חוזר",
-    "Message sent!" : "הודעה נשלחה!",
     "Add share link from {productName} Files" : "הוספת קישור שיתוף מקבצים של {productName}",
     "Send" : "שליחה",
-    "Encrypt and send" : "להצפין ולשלוח",
-    "Send unencrypted" : "לשלוח ללא הצפנה",
     "Message {id} could not be found" : "לא ניתן למצוא את הודעה {id}",
     "Choose a file to add as attachment" : "בחירת קובץ להוספה כקובץ מצורף",
     "Choose a file to share as a link" : "נא לבחור קובץ לשיתוף כקישור",
@@ -103,7 +97,6 @@ OC.L10N.register(
     "Unselect" : "ביטול בחירה",
     "Select" : "בחירה",
     "Edit tags" : "עריכת תגיות",
-    "Move" : "העברה",
     "Move thread" : "העברת שרשור",
     "Delete thread" : "מחיקת שרשור",
     "More actions" : "פעולות נוספות",
@@ -142,6 +135,7 @@ OC.L10N.register(
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "הודעה זו מוצפנת עם PGP. יש להתקין את Mailvelope כדי לפענח אותה.",
     "The images have been blocked to protect your privacy." : "התמונות נחסמו כדי להגן על הפרטיות שלך",
     "Message frame" : "מסגרת הודעה",
+    "Move" : "העברה",
     "Quota" : "מכיסה",
     "Add mailbox" : "הוספת תיבת דוא״ל",
     "Saving" : "שמירה",
@@ -167,6 +161,11 @@ OC.L10N.register(
     "_{total} message_::_{total} messages_" : ["הודעה אחת","{total} הודעות","{total} הודעות","{total} הודעות"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["אחת לא נקראה מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}"],
     "New message" : "הודעה חדשה",
+    "Error sending your message" : "שליחת ההודעה שלך נכשלה",
+    "Go back" : "חזרה",
+    "Retry" : "ניסיון חוזר",
+    "Uploading attachments …" : "הקבצים המצורפים מועלים…",
+    "Sending …" : "שולח...",
     "No message selected" : "לא נבחרה הודעה",
     "Message" : "הודעה",
     "Oh Snap!" : "שוד ושבר!",
@@ -212,6 +211,7 @@ OC.L10N.register(
     "Mail app" : "יישומון דוא״ל",
     "The mail app allows users to read mails on their IMAP accounts." : "יישומון הדוא״ל מאפשר למשתמשים לקרוא הודעות דוא״ל בחשבונות ה־IMAP שלהם.",
     "Reset" : "איפוס",
+    "Client ID" : "מזהה לקו",
     "Client secret" : "סוד לקוח",
     "Email: {email}" : "דוא״ל: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP:‏ {user} על גבי ‎{host}:{port}‎ (הצפנת {ssl})",
@@ -225,7 +225,11 @@ OC.L10N.register(
     "SMTP" : "SMTP",
     "Save Config" : "שמירת הגדרות",
     "With the settings above, the app will create account settings in the following way:" : "עם ההגדרות שלהלן, היישומון יצור הגדרות חשבון באופן הבא:",
-    "Account connected" : "חשבון מחובר",
+    "E-mail address" : "כתובת דוא״ל",
+    "Valid until" : "בתוקף עד",
+    "Certificate" : "אישור",
+    "Back" : "חזרה",
+    "Submit" : "שליחה",
     "Keyboard shortcut" : "קיצור מקלדת",
     "Keyboard shortcuts" : "קיצורי מקלדת",
     "Speed up your Mail experience with these quick shortcuts." : "ניתן להאיץ את חוויית הדוא״ל שלך עם קיצורי המקלדת הזריזים האלו.",
@@ -234,11 +238,12 @@ OC.L10N.register(
     "Older message" : "הודעה ישנה יותר",
     "Toggle star" : "החלפת מצב כוכב",
     "Toggle unread" : "החלפת מצב קריאה",
+    "Archive" : "לארכיון",
     "Refresh" : "רענון",
+    "Account connected" : "חשבון מחובר",
     "Connect your mail account" : "התחברות לחשבון הדוא״ל שלך",
     "Itinerary for {type} is not supported yet" : "פירוט המסלול {type} אינו נתמך עדיין",
     "All" : "הכול",
-    "Archive" : "לארכיון",
     "Drafts" : "טיוטות",
     "Favorites" : "מועדפים",
     "Priority inbox" : "תיבת דואר נכנס בעדיפות",
