@@ -38,8 +38,8 @@ OC.L10N.register(
     "Connecting" : "Povezivanje",
     "Save" : "Spremi",
     "Connect" : "Poveži",
+    "Password required" : "Potrebna zaporka",
     "Account settings" : "Postavke računa",
-    "Change name" : "Promijeni ime",
     "Signature" : "Potpis",
     "A signature is added to the text of new messages and replies." : "Tekstu novih poruka i odgovora dodaje se potpis.",
     "Writing mode" : "Način pisanja",
@@ -52,6 +52,7 @@ OC.L10N.register(
     "Update alias" : "Ažuriraj pseudonim",
     "Show update alias form" : "Prikaži obrazac za ažuriranje pseudonima",
     "Delete alias" : "Izbriši pseudonim",
+    "Change name" : "Promijeni ime",
     "Email address" : "Adresa e-pošte",
     "Add alias" : "Dodaj pseudonim",
     "Create alias" : "Stvori pseudonim",
@@ -80,25 +81,14 @@ OC.L10N.register(
     "Draft saved" : "Skica je spremljena",
     "Upload attachment" : "Otpremi privitak",
     "Add attachment from Files" : "Dodaj privitak iz datoteka",
+    "Add link" : "Dodaj poveznicu",
     "Enable formatting" : "Omogući oblikovanje",
     "Request a read receipt" : "Zatražite potvrdu o čitanju",
     "Encrypt message with Mailvelope" : "Šifriraj poruku s Mailvelope",
     "Enter a date" : "Unesi datum",
-    "Uploading attachments …" : "Otpremanje privitaka...",
-    "Sending …" : "Slanje…",
-    "Error sending your message" : "Pogreška pri slanju poruke",
-    "Go back" : "Natrag",
-    "Retry" : "Pokušaj ponovno",
-    "Warning sending your message" : "Upozorenje pri slanju poruke",
-    "Send anyway" : "Svejedno pošalji",
-    "Message sent!" : "Poruka poslana!",
     "Add share link from {productName} Files" : "Dodaj poveznicu za dijeljenje iz datoteka {productName}",
     "Send" : "Pošalji",
-    "Encrypt and send" : "Šifriraj i pošalji",
-    "Send unencrypted" : "Pošalji nešifrirano",
     "Message {id} could not be found" : "Poruka {id} nije pronađena",
-    "No sent mailbox configured. Please pick one in the account settings." : "Nije konfiguriran sandučić za poslanu poštu. Odaberite ga u postavkama računa.",
-    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Pokušavate poslati poruku velikom broju primatelja koji su navedeni u poljima Za i/ili Cc. Razmislite o korištenju polja Bcc kako adrese primatelja ne bi bile vidljive.",
     "Choose a file to add as attachment" : "Izaberi datoteku kao privitak",
     "Choose a file to share as a link" : "Izaberi datoteku za dijeljenje putem poveznice",
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Privitak prekoračuje dopuštenu veličinu privitaka od {size}. Dijelite datoteku putem poveznice.","Privici prekoračuju dopuštenu veličinu privitaka od {size}. Dijelite datoteke putem poveznice.","Privici prekoračuju dopuštenu veličinu privitaka od {size}. Dijelite datoteke putem poveznice."],
@@ -117,7 +107,6 @@ OC.L10N.register(
     "Unselect" : "Poništi odabir",
     "Select" : "Odaberi",
     "Edit tags" : "Uredi oznake",
-    "Move" : "Premjesti",
     "Move thread" : "Premjesti dretvu",
     "Delete thread" : "Izbriši dretvu",
     "More actions" : "Dodatne radnje",
@@ -183,6 +172,7 @@ OC.L10N.register(
     "Always show images from {domain}" : "Uvijek prikaži slike s {domain}",
     "Message frame" : "Okvir poruke",
     "Quoted text" : "Citirani tekst",
+    "Move" : "Premjesti",
     "Moving" : "Premještanje",
     "Moving thread" : "Premještanje dretve",
     "Moving message" : "Premještanje poruke",
@@ -217,6 +207,15 @@ OC.L10N.register(
     "_{total} message_::_{total} messages_" : ["{total} poruka","{total} poruka","{total} poruka"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} nepročitana od {total}","{unread} nepročitane od {total}","{unread} nepročitanih od {total}"],
     "New message" : "Nova poruka",
+    "Error sending your message" : "Pogreška pri slanju poruke",
+    "Go back" : "Natrag",
+    "Retry" : "Pokušaj ponovno",
+    "Uploading attachments …" : "Otpremanje privitaka...",
+    "Sending …" : "Slanje…",
+    "Warning sending your message" : "Upozorenje pri slanju poruke",
+    "Send anyway" : "Svejedno pošalji",
+    "No sent mailbox configured. Please pick one in the account settings." : "Nije konfiguriran sandučić za poslanu poštu. Odaberite ga u postavkama računa.",
+    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Pokušavate poslati poruku velikom broju primatelja koji su navedeni u poljima Za i/ili Cc. Razmislite o korištenju polja Bcc kako adrese primatelja ne bi bile vidljive.",
     "No message selected" : "Nije odabrana nijedna poruka",
     "Message" : "Poruka",
     "Oh Snap!" : "Oh Snap!",
@@ -314,6 +313,7 @@ OC.L10N.register(
     "Error saving anti spam email addresses" : "Pogreška pri spremanju adresa e-pošte za sprječavanje neželjene pošte",
     "Successfully deleted anti spam reporting email" : "Uspješno izbrisana adresa e-pošte za prijavu neželjene pošte",
     "Error deleting anti spam reporting email" : "Pogreška pri brisanju adrese e-pošte za prijavu neželjene pošte",
+    "Client ID" : "ID klijenta",
     "Client secret" : "Tajni ključ klijenta",
     "Domain Match: {provisioningDomain}" : "Podudaranje domene: {provisioningDomain}",
     "Email: {email}" : "E-pošta: {email}",
@@ -340,7 +340,11 @@ OC.L10N.register(
     "Unprovision & Delete Config" : "Ukini dodjelu i izbriši konfiguraciju",
     "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% i %EMAIL% bit će zamijenjeni korisničkim UID-om i e-poštom",
     "With the settings above, the app will create account settings in the following way:" : "Aplikacija će primijeniti navedene postavke i stvoriti račun na sljedeći način:",
-    "Account connected" : "Račun povezan",
+    "E-mail address" : "Adresa e-pošte",
+    "Valid until" : "Vrijedi do",
+    "Certificate" : "Vjerodajnica",
+    "Back" : "Natrag",
+    "Submit" : "Šalji",
     "Keyboard shortcut" : "Tipkovni prečac",
     "Keyboard shortcuts" : "Tipkovni prečaci",
     "Speed up your Mail experience with these quick shortcuts." : "Ubrzajte korištenje e-pošte s pomoću ovih brzih prečaca.",
@@ -349,11 +353,12 @@ OC.L10N.register(
     "Older message" : "Starija poruka",
     "Toggle star" : "Uključi/isključi zvijezdu",
     "Toggle unread" : "Uključi/isključi nepročitano",
+    "Archive" : "Arhiva",
     "Refresh" : "Osvježi",
+    "Account connected" : "Račun povezan",
     "Connect your mail account" : "Poveži svoj račun e-pošte",
     "Itinerary for {type} is not supported yet" : "Raspored za {type} još uvijek nije podržan",
     "All" : "Sve",
-    "Archive" : "Arhiva",
     "Drafts" : "Skice",
     "Favorites" : "Favoriti",
     "Priority inbox" : "Prioritetni sandučić",
