@@ -34,13 +34,14 @@ OC.L10N.register(
     "Connecting" : "Tengist",
     "Save" : "Vista",
     "Connect" : "Tengjast",
+    "Password required" : "Lykilorðs er krafist",
     "Account settings" : "Stillingar notandaaðgangs",
-    "Change name" : "Breyta nafni",
     "Signature" : "Undirskrift",
     "A signature is added to the text of new messages and replies." : "Undirskrift verður bætt við texta nýrra skilaboða og svarpósta.",
     "Writing mode" : "Skrifhamur",
     "Preferred writing mode for new messages and replies." : "Umbeðinn skrifhamur við gerð nýrra skilaboða og svarpósta.",
     "Mail server" : "Póstþjónn",
+    "Change name" : "Breyta nafni",
     "Email address" : "Tölvupóstfang",
     "Add alias" : "Bæta við samheiti",
     "Cancel" : "Hætta við",
@@ -64,17 +65,10 @@ OC.L10N.register(
     "Draft saved" : "Drög vistuð",
     "Upload attachment" : "Senda inn viðhengi",
     "Add attachment from Files" : "Bæta við viðhengi úr skrám",
+    "Add link" : "Bæta við tengli",
     "Enable formatting" : "Virkja sniðmótun",
     "Encrypt message with Mailvelope" : "Dulrita skilaboð með Mailvelope",
-    "Uploading attachments …" : "Sendi inn viðhengi…",
-    "Sending …" : "Sendi ...",
-    "Error sending your message" : "Villa við að senda skilaboðin þín",
-    "Go back" : "Fara til baka",
-    "Retry" : "Reyna aftur",
-    "Message sent!" : "Skilaboðin hafa verið send!",
     "Send" : "Senda",
-    "Encrypt and send" : "Dulrita og senda",
-    "Send unencrypted" : "Senda ódulritað",
     "Choose a file to add as attachment" : "Veldu skrá til að setja sem viðhengi",
     "Choose a file to share as a link" : "Veldu skrá til að deila sem tengli",
     "No message found yet" : "Engin skilaboð hafa ennþá fundist",
@@ -91,7 +85,6 @@ OC.L10N.register(
     "Unselect" : "Afvelja",
     "Select" : "Velja",
     "Edit tags" : "Breyta merkjum",
-    "Move" : "Færa",
     "More actions" : "Fleiri aðgerðir",
     "Edit as new message" : "Breyta sem nýjum skilaboðum",
     "Create event" : "Búa til atburð",
@@ -129,6 +122,7 @@ OC.L10N.register(
     "Show images" : "Sýna myndir",
     "Message frame" : "Rammi skilaboða",
     "Quoted text" : "Tilvitnaður texti",
+    "Move" : "Færa",
     "Moving" : "Færi",
     "Quota" : "Kvóti",
     "Saving" : "Vista",
@@ -150,6 +144,11 @@ OC.L10N.register(
     "_{total} message_::_{total} messages_" : ["{total} skilaboð","{total} skilaboð"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} ólesið af {total}","{unread} ólesin af {total}"],
     "New message" : "Ný skilaboð",
+    "Error sending your message" : "Villa við að senda skilaboðin þín",
+    "Go back" : "Fara til baka",
+    "Retry" : "Reyna aftur",
+    "Uploading attachments …" : "Sendi inn viðhengi…",
+    "Sending …" : "Sendi ...",
     "No message selected" : "Engin skilaboð valin",
     "Message" : "Skilaboð",
     "Delete" : "Eyða",
@@ -199,7 +198,10 @@ OC.L10N.register(
     "Port" : "Gátt",
     "SMTP" : "SMTP",
     "With the settings above, the app will create account settings in the following way:" : "Með stillingunum hér fyrir ofan, mun forritið útbúa aðgangsstillingar á eftirfarandi máta:",
-    "Account connected" : "Aðgangur er tengdur",
+    "Valid until" : "Gildir til",
+    "Certificate" : "Skilríki",
+    "Back" : "Til baka",
+    "Submit" : "Senda inn",
     "Keyboard shortcut" : "Flýtilykill",
     "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
     "Speed up your Mail experience with these quick shortcuts." : "Flýttu fyrir vinnu þinni með póst með þessum flýtilyklum.",
@@ -208,11 +210,12 @@ OC.L10N.register(
     "Older message" : "Eldri skilaboð",
     "Toggle star" : "Víxla stjörnumerkingu af/á",
     "Toggle unread" : "Víxla ólesnu af/á",
+    "Archive" : "Setja í safnskrá",
     "Refresh" : "Endurlesa",
+    "Account connected" : "Aðgangur er tengdur",
     "Connect your mail account" : "Tengdu notandaaðganginn þinn",
     "Itinerary for {type} is not supported yet" : "Það er ekki ennþá stuðningur við leið af gerðinni {type}",
     "All" : "Allt",
-    "Archive" : "Setja í safnskrá",
     "Drafts" : "Drög",
     "Favorites" : "Eftirlæti",
     "Priority inbox" : "Forgangspósthólf",
