@@ -12,6 +12,7 @@ OC.L10N.register(
     "Mails" : "Messaggi di posta",
     "Mail" : "Posta",
     "💌 A mail app for Nextcloud" : "💌 Un'applicazione di posta per Nextcloud",
+    "Your session has expired. The page will be reloaded." : "La sessione è scaduta. La pagina verrà ricaricata.",
     "Drafts are saved in:" : "Le bozze sono salvate in:",
     "Sent messages are saved in:" : "I messaggi inviati sono salvati in:",
     "Deleted messages are moved in:" : "I messaggi eliminati sono spostati in:",
@@ -39,8 +40,8 @@ OC.L10N.register(
     "Sign in with Google" : "Accedi con Google",
     "Save" : "Salva",
     "Connect" : "Connetti",
+    "Password required" : "Password richiesta",
     "Account settings" : "Impostazioni account",
-    "Change name" : "Cambia il nome",
     "Signature" : "Firma",
     "A signature is added to the text of new messages and replies." : "Una firma sarà aggiunta al testo dei nuovi messaggi e delle risposte.",
     "Writing mode" : "Modalità di scrittura",
@@ -53,6 +54,7 @@ OC.L10N.register(
     "Update alias" : "Aggiorna alias",
     "Show update alias form" : "Mostra modulo aggiornamento alias",
     "Delete alias" : "Elimina alias",
+    "Change name" : "Cambia il nome",
     "Email address" : "Indirizzo email",
     "Add alias" : "Aggiungi alias",
     "Create alias" : "Crea alias",
@@ -82,25 +84,14 @@ OC.L10N.register(
     "Discard & close draft" : "Scarta e chiudi bozza",
     "Upload attachment" : "Carica allegato",
     "Add attachment from Files" : "Aggiungi allegato da File",
+    "Add link" : "Aggiungi collegamento",
     "Enable formatting" : "Abilita formattazione",
     "Request a read receipt" : "Richiedi una conferma di lettura",
     "Encrypt message with Mailvelope" : "Cifra il messaggio con Mailvelope",
     "Enter a date" : "Digita una data",
-    "Uploading attachments …" : "Caricamento allegati…",
-    "Sending …" : "Invio in corso...",
-    "Error sending your message" : "Errore di invio del messaggio",
-    "Go back" : "Indietro",
-    "Retry" : "Riprova",
-    "Warning sending your message" : "Avviso durante l'invio del tuo messaggio",
-    "Send anyway" : "Invia comunque",
-    "Message sent!" : "Messaggio inviato!",
     "Add share link from {productName} Files" : "Aggiungi collegamento di condivisione da {productName} File",
     "Send" : "Invia",
-    "Encrypt and send" : "Cifra e invia",
-    "Send unencrypted" : "Invia in chiaro",
     "Message {id} could not be found" : "Il messaggio {id} non può essere trovato",
-    "No sent mailbox configured. Please pick one in the account settings." : "Nessuna casella di posta inviata configurata. Scegline una nelle impostazioni dell'account.",
-    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Stai tentando di inviare a troppi destinatari in A e/o CC. Considera l'idea di utilizzare CCN per nascondere gli indirizzi dei destinatari.",
     "Choose a file to add as attachment" : "Scegli un file da aggiungere come allegato",
     "Choose a file to share as a link" : "Scegli un file da condividere come un collegamento",
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Gli allegati superano le dimensioni consentite per gli allegati di {size}. Condividere invece il file tramite collegamento.","Gli allegati superano le dimensioni consentite per gli allegati di {size}. Condividere invece i file tramite collegamento.","Gli allegati superano le dimensioni consentite per gli allegati di {size}. Condividere invece i file tramite collegamento."],
@@ -121,7 +112,6 @@ OC.L10N.register(
     "Unselect" : "Deseleziona",
     "Select" : "Seleziona",
     "Edit tags" : "Modifica etichette",
-    "Move" : "Sposta",
     "Move thread" : "Sposta conversazione",
     "Delete thread" : "Elimina conversazione",
     "More actions" : "Altre azioni",
@@ -188,9 +178,11 @@ OC.L10N.register(
     "Always show images from {domain}" : "Mostra sempre le immagini da {domain}",
     "Message frame" : "Riquadro del messaggio",
     "Quoted text" : "Testo citato",
+    "Move" : "Sposta",
     "Moving" : "Spostamento",
     "Moving thread" : "Spostamento conversazione",
     "Moving message" : "Spostamento messaggio",
+    "Mail settings" : "Impostazioni Posta",
     "Quota" : "Quote",
     "Show only subscribed mailboxes" : "Mostra solo le caselle di posta sottoscritte",
     "Add mailbox" : "Aggiungi casella di posta",
@@ -222,6 +214,15 @@ OC.L10N.register(
     "_{total} message_::_{total} messages_" : ["{total} messaggio","{total} messaggi","{total} messaggi"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} non letto di {total}","{unread} non letti di {total}","{unread} non letti di {total}"],
     "New message" : "Nuovo messaggio",
+    "Error sending your message" : "Errore di invio del messaggio",
+    "Go back" : "Indietro",
+    "Retry" : "Riprova",
+    "Uploading attachments …" : "Caricamento allegati…",
+    "Sending …" : "Invio in corso...",
+    "Warning sending your message" : "Avviso durante l'invio del tuo messaggio",
+    "Send anyway" : "Invia comunque",
+    "No sent mailbox configured. Please pick one in the account settings." : "Nessuna casella di posta inviata configurata. Scegline una nelle impostazioni dell'account.",
+    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Stai tentando di inviare a troppi destinatari in A e/o CC. Considera l'idea di utilizzare CCN per nascondere gli indirizzi dei destinatari.",
     "No message selected" : "Nessun messaggio selezionato",
     "Message" : "Messaggio",
     "Oh Snap!" : "Accidenti!",
@@ -347,7 +348,11 @@ OC.L10N.register(
     "Unprovision & Delete Config" : "Annullare il approvvigionamento ed eliminare la configurazione",
     "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% e %EMAIL% verranno sostituiti con l'UID e l'e-mail dell'utente",
     "With the settings above, the app will create account settings in the following way:" : "Con le impostazioni precedenti, l'applicazione creerà le impostazioni dell'account nel modo seguente:",
-    "Account connected" : "Account connesso",
+    "E-mail address" : "Indirizzo di posta",
+    "Valid until" : "Valido fino al",
+    "Certificate" : "Certificato",
+    "Back" : "Indietro",
+    "Submit" : "Invia",
     "Keyboard shortcut" : "Scorciatoia da tastiera",
     "Keyboard shortcuts" : "Scorciatoie da tastiera",
     "Speed up your Mail experience with these quick shortcuts." : "Velocizza la tua esperienza di posta elettronica con queste scorciatoie.",
@@ -356,11 +361,12 @@ OC.L10N.register(
     "Older message" : "Messaggio più datato",
     "Toggle star" : "Commuta stella",
     "Toggle unread" : "Commuta non letto",
+    "Archive" : "Archivio",
     "Refresh" : "Aggiorna",
+    "Account connected" : "Account connesso",
     "Connect your mail account" : "Connetti il tuo account di posta",
     "Itinerary for {type} is not supported yet" : "L'itinerario per {type} non è ancora supportato",
     "All" : "Tutti",
-    "Archive" : "Archivio",
     "Drafts" : "Bozze",
     "Favorites" : "Preferiti",
     "Priority inbox" : "Posta in arrivo prioritaria",
