@@ -37,8 +37,8 @@ OC.L10N.register(
     "Connecting" : "接続中",
     "Save" : "保存",
     "Connect" : "接続",
+    "Password required" : "パスワードが必要です",
     "Account settings" : "アカウント設定",
-    "Change name" : "名称変更",
     "Signature" : "署名",
     "A signature is added to the text of new messages and replies." : "署名は、新しいメッセージと返信の本文に追加されます。",
     "Writing mode" : "書き込みモード",
@@ -46,6 +46,7 @@ OC.L10N.register(
     "Default folders" : "デフォルトフォルダー",
     "Mail server" : "メールサーバー",
     "Delete alias" : "別名を削除",
+    "Change name" : "名称変更",
     "Email address" : "メールアドレス",
     "Add alias" : "別名を追加",
     "Create alias" : "別名をつける",
@@ -72,18 +73,11 @@ OC.L10N.register(
     "Draft saved" : "下書きを保存しました。",
     "Upload attachment" : "添付ファイルをアップロードする",
     "Add attachment from Files" : "ファイルから添付ファイルの追加",
+    "Add link" : "リンクを追加",
     "Enable formatting" : "フォーマットを有効にする",
     "Encrypt message with Mailvelope" : "Mailvelopeでメッセージを暗号化",
     "Enter a date" : "日付を入力してください",
-    "Uploading attachments …" : "添付ファイルをアップロード",
-    "Sending …" : "送信中 …",
-    "Error sending your message" : "メッセージ送信エラー",
-    "Go back" : "戻る",
-    "Retry" : "再試行",
-    "Message sent!" : "へメッセージを送信しました！",
     "Send" : "送信",
-    "Encrypt and send" : "暗号化して送信",
-    "Send unencrypted" : "暗号化せずに送信",
     "Message {id} could not be found" : "メッセージ {id} が見つかりません",
     "Choose a file to add as attachment" : "添付として追加するファイルを選択",
     "Choose a file to share as a link" : "共有リンクにして送信するファイルを選択",
@@ -102,7 +96,6 @@ OC.L10N.register(
     "Unselect" : "選択解除",
     "Select" : "選択",
     "Edit tags" : "タグを編集",
-    "Move" : "移動",
     "Delete thread" : "スレッドを削除",
     "More actions" : "その他のアクション",
     "Edit as new message" : "新しいメッセージとして編集",
@@ -147,6 +140,7 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "画像はあなたのプライバシーを守るためにブロックされています。",
     "Show images" : "画像を表示する",
     "Show images temporarily" : "画像を一時的に表示",
+    "Move" : "移動",
     "Moving" : "移動中",
     "Quota" : "クオータ",
     "Show only subscribed mailboxes" : "購読したメールボックスのみ表示",
@@ -178,6 +172,11 @@ OC.L10N.register(
     "_{total} message_::_{total} messages_" : ["{total} メッセージ"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{total} メッセージの内 {unread} 件が未開封"],
     "New message" : "新規メッセージ",
+    "Error sending your message" : "メッセージ送信エラー",
+    "Go back" : "戻る",
+    "Retry" : "再試行",
+    "Uploading attachments …" : "添付ファイルをアップロード",
+    "Sending …" : "送信中 …",
     "No message selected" : "メッセージが選択されていません。",
     "Message" : "メッセージ",
     "Oh Snap!" : "おっと！",
@@ -243,7 +242,11 @@ OC.L10N.register(
     "SMTP" : "SMTP",
     "Save Config" : "設定を保存",
     "With the settings above, the app will create account settings in the following way:" : "上記の設定では、アプリは次の方法でアカウント設定を作成します：",
-    "Account connected" : "アカウント接続済",
+    "E-mail address" : "メールアドレス",
+    "Valid until" : "有効期限",
+    "Certificate" : "証明",
+    "Back" : "戻る",
+    "Submit" : "送信",
     "Keyboard shortcut" : "キーボードショートカット",
     "Keyboard shortcuts" : "キーボード ショートカット",
     "Speed up your Mail experience with these quick shortcuts." : "ショートカットであなたのメール操作をスピードアップしてください。",
@@ -252,11 +255,12 @@ OC.L10N.register(
     "Older message" : "古いメッセージ",
     "Toggle star" : "スターを切り替え",
     "Toggle unread" : "未読を切り替え",
+    "Archive" : "アーカイブ",
     "Refresh" : "同期",
+    "Account connected" : "アカウント接続済",
     "Connect your mail account" : "あなたのメールアカウントに接続",
     "Itinerary for {type} is not supported yet" : "{type} タイプの旅程はまだサポートされていません",
     "All" : "すべて",
-    "Archive" : "アーカイブ",
     "Drafts" : "草稿",
     "Favorites" : "お気に入り",
     "Priority inbox" : "優先受信箱",
