@@ -11,21 +11,35 @@ OC.L10N.register(
     "Cancel" : "Sefsex",
     "Send" : "Tuzna",
     "Favorite" : "Menyif",
-    "Move" : "Senkez",
+    "Select" : "Fren",
     "Forward" : "Avancer",
     "Create" : "Snulfu-d",
+    "Comment" : "Commentaire",
     "Choose" : "Fren",
+    "Other" : "Wayeḍ",
+    "Reply" : "Err",
+    "Move" : "Senkez",
+    "Retry" : "Ɛreḍ tikkelt-nniḍen",
     "Message" : "Izen",
     "Delete" : "Kkes",
+    "Copy to clipboard" : "Copier dans le presse-papiers",
     "Add" : "Rnu",
     "Tags" : "Tibzimin",
     "Search" : "Nadi",
+    "Disabled" : "Ittwarermed",
+    "Enabled" : "Yermed",
+    "Set" : "Sbadu",
     "Unset" : "Non défini",
+    "Mark as unread" : "Creḍ ur yettwaɣra ara",
+    "Mark as read" : "Creḍ yettwaɣra",
     "Remove" : "Kkes",
     "General" : "Amatu",
     "User" : "Aseqdac",
+    "Back" : "Retour",
     "Refresh" : "Sismeḍ",
+    "All" : "Akk",
     "Favorites" : "Imenyafen",
-    "Inbox" : "Tanaka"
+    "Inbox" : "Tanaka",
+    "Message sent" : "Izen yettwazen"
 },
 "nplurals=2; plural=(n != 1);");
