@@ -38,10 +38,10 @@ OC.L10N.register(
     "Connecting" : "연결 중",
     "Save" : "저장",
     "Connect" : "연결",
+    "Password required" : "암호가 필요함",
     "Account updated" : "계정 업데이트됨",
     "There was an error while setting up your account" : "계정을 설정하는 중 오류가 발생했습니다",
     "Account settings" : "계정 설정",
-    "Change name" : "이름 변경",
     "Signature" : "서명",
     "A signature is added to the text of new messages and replies." : "서명이 새로운 메시지 및 전달 메시지의 텍스트에 추가됩니다.",
     "Writing mode" : "쓰기 모드",
@@ -49,6 +49,7 @@ OC.L10N.register(
     "Default folders" : "기본 폴더",
     "Trusted senders" : "신뢰할 수 있는 발신자",
     "Mail server" : "메일 서버",
+    "Change name" : "이름 변경",
     "Email address" : "이메일 주소",
     "Add alias" : "별칭 추가",
     "Cancel" : "취소",
@@ -79,6 +80,7 @@ OC.L10N.register(
     "Save draft" : "초안 저장",
     "Upload attachment" : "첨부 파일 업로드",
     "Add attachment from Files" : "파일 앱에서 첨부 파일 추가",
+    "Add link" : "링크 추가",
     "Send later" : "나중에 보내기",
     "Enable formatting" : "서식 활성화",
     "Request a read receipt" : "수신 확인 요청",
@@ -89,16 +91,7 @@ OC.L10N.register(
     "Monday morning" : "월요일 아침",
     "Custom date and time" : "사용자 지정 날짜 및 시간",
     "Enter a date" : "날짜 입력",
-    "Uploading attachments …" : "첨부 파일 업로드...",
-    "Sending …" : "보내는 중...",
-    "Error sending your message" : "당신의 메시지 보내기 오류",
-    "Go back" : "뒤로 가기",
-    "Retry" : "다시 시도",
-    "Warning sending your message" : "메시지 전송 경고",
-    "Message sent!" : "메시지를 보냈습니다!",
     "Send" : "보내기",
-    "Encrypt and send" : "암호화해서 보내기",
-    "Send unencrypted" : "비암호화 발송",
     "Choose a file to add as attachment" : "첨부할 파일을 선택하십시오",
     "Choose a file to share as a link" : "공유할 링크 파일을 선택하십시오",
     "Set up an account" : "계정 설정",
@@ -114,7 +107,6 @@ OC.L10N.register(
     "Unselect" : "선택 해제",
     "Select" : "선택",
     "Edit tags" : "태그 편집",
-    "Move" : "이동",
     "More actions" : "더 많은 동작",
     "Create event" : "일정 만들기",
     "Forward" : "전달",
@@ -139,6 +131,7 @@ OC.L10N.register(
     "Save all to Files" : "모두 저장",
     "The images have been blocked to protect your privacy." : "개인 정보를 보호하기 위해 사진을 차단했습니다.",
     "Show images" : "사진 보이기",
+    "Move" : "이동",
     "Quota" : "할당량",
     "Saving" : "저장 중",
     "Move up" : "위로 이동",
@@ -153,6 +146,12 @@ OC.L10N.register(
     "Subscribed" : "구독함",
     "_{total} message_::_{total} messages_" : ["{total} 개의 메시지"],
     "New message" : "새로운 메시지",
+    "Error sending your message" : "당신의 메시지 보내기 오류",
+    "Go back" : "뒤로 가기",
+    "Retry" : "다시 시도",
+    "Uploading attachments …" : "첨부 파일 업로드...",
+    "Sending …" : "보내는 중...",
+    "Warning sending your message" : "메시지 전송 경고",
     "Message" : "메시지",
     "Delete" : "삭제",
     "Copy to clipboard" : "클립보드로 복사",
@@ -192,7 +191,11 @@ OC.L10N.register(
     "Port" : "포트",
     "SMTP" : "SMTP",
     "With the settings above, the app will create account settings in the following way:" : "상단의 설정을 통해, 앱은 다음의 방법으로 계정 설정을 생성합니다: ",
-    "Account connected" : "계정 연결됨",
+    "E-mail address" : "이메일 주소",
+    "Valid until" : "만료 기간:",
+    "Certificate" : "인증서",
+    "Back" : "뒤로",
+    "Submit" : "제출",
     "Keyboard shortcut" : "키보드 단축키",
     "Keyboard shortcuts" : "키보드 단축키",
     "Speed up your Mail experience with these quick shortcuts." : "빠른 단축키로 메일 사용을 더 빠르게 할 수 있습니다.",
@@ -201,11 +204,12 @@ OC.L10N.register(
     "Older message" : "오래된 메시지",
     "Toggle star" : "별표 전환",
     "Toggle unread" : "읽음/읽지 않음 전환",
+    "Archive" : "보관",
     "Refresh" : "새로 고침",
+    "Account connected" : "계정 연결됨",
     "Connect your mail account" : "메일 계정에 연결",
     "To add a mail account, please contact your administrator." : "이메일 계정 추가는 관리자에게 문의하십시오.",
     "All" : "모두",
-    "Archive" : "보관",
     "Drafts" : "임시 보관함",
     "Favorites" : "즐겨찾기",
     "Priority inbox" : "우선 받은편지함",
