@@ -42,6 +42,7 @@ OC.L10N.register(
     "Looking up configuration" : "Ieškoma konfigūracijos",
     "Checking mail host connectivity" : "Tikrinamas jungiamumas su pašto serveriu",
     "Configuration discovery failed. Please use the manual settings" : "Nepavyko atrasti konfigūracijos. Naudokite rankinius nustatymus",
+    "Password required" : "Reikalingas slaptažodis",
     "Testing authentication" : "Išbandomas tapatybės nustatymas",
     "Account updated" : "Paskyra atnaujinta",
     "IMAP server is not reachable" : "IMAP serveris yra nepasiekiamas",
@@ -52,7 +53,6 @@ OC.L10N.register(
     "SMTP connection failed" : "SMTP ryšys patyrė nesėkmę",
     "There was an error while setting up your account" : "Nustatant jūsų paskyrą įvyko klaida",
     "Account settings" : "Paskyros nustatymai",
-    "Change name" : "Keisti vardą",
     "Signature" : "Parašas",
     "A signature is added to the text of new messages and replies." : "Parašas yra pridedamas į naujų ir atsakomųjų laiškų tekstą.",
     "Writing mode" : "Rašymo veiksena",
@@ -62,6 +62,7 @@ OC.L10N.register(
     "Autoresponder" : "Atsakiklis",
     "Trusted senders" : "Patikimi siuntėjai",
     "Mail server" : "Pašto serveris",
+    "Change name" : "Keisti vardą",
     "Email address" : "El. pašto adresas",
     "Add alias" : "Pridėti alternatyvų vardą",
     "Cancel" : "Atsisakyti",
@@ -91,22 +92,14 @@ OC.L10N.register(
     "Discard & close draft" : "Atmesti ir užverti juodraštį",
     "Upload attachment" : "Įkelti priedą",
     "Add attachment from Files" : "Pridėti priedą iš Failų",
+    "Add link" : "Pridėti nuorodą",
     "Send later" : "Siųsti vėliau",
     "Enable formatting" : "Įjungti formatavimą",
     "Disable formatting" : "Išjungti formatavimą",
     "Encrypt message with Mailvelope" : "Šifruoti laišką naudojant Mailvelope",
     "Send now" : "Siųsti dabar",
     "Enter a date" : "Įveskite datą",
-    "Uploading attachments …" : "Įkeliami priedai …",
-    "Sending …" : "Siunčiama …",
-    "Error sending your message" : "Klaida siunčiant jūsų laišką",
-    "Go back" : "Grįžti",
-    "Retry" : "Bandyti dar kartą",
-    "Send anyway" : "Vis tiek siųsti",
-    "Message sent!" : "Laiškas išsiųstas!",
     "Send" : "Siųsti",
-    "Encrypt and send" : "Šifruoti ir siųsti",
-    "Send unencrypted" : "Siųsti nešifruotą",
     "Turn off formatting" : "Išjungti formatavimą",
     "Turn off and remove formatting" : "Išjungti ir šalinti formatavimą",
     "Keep formatting" : "Palikti formatavimą",
@@ -128,7 +121,6 @@ OC.L10N.register(
     "Unselect" : "Nuimti žymėjimą",
     "Select" : "Pasirinkti",
     "Edit tags" : "Redaguoti žymes",
-    "Move" : "Perkelti",
     "More actions" : "Daugiau veiksmų",
     "Edit as new message" : "Taisyti kaip naują laišką",
     "Create event" : "Sukurti įvykį",
@@ -179,6 +171,7 @@ OC.L10N.register(
     "Always show images from {sender}" : "Visada rodyti paveikslus nuo {sender}",
     "Always show images from {domain}" : "Visada rodyti paveikslus iš {domain}",
     "Quoted text" : "Cituojamas tekstas",
+    "Move" : "Perkelti",
     "Mail settings" : "Pašto nustatymai",
     "Quota" : "Leidžiamas duomenų kiekis",
     "Show only subscribed mailboxes" : "Rodyti tik prenumeruotas pašto dėžutes",
@@ -209,6 +202,12 @@ OC.L10N.register(
     "_{total} message_::_{total} messages_" : ["{total} laiškas","{total} laiškai","{total} laiškų","{total} laiškas"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} neskaitytas iš {total}","{unread} neskaityti iš {total}","{unread} neskaitytų iš {total}","{unread} neskaitytas iš {total}"],
     "New message" : "Naujas laiškas",
+    "Error sending your message" : "Klaida siunčiant jūsų laišką",
+    "Go back" : "Grįžti",
+    "Retry" : "Bandyti dar kartą",
+    "Uploading attachments …" : "Įkeliami priedai …",
+    "Sending …" : "Siunčiama …",
+    "Send anyway" : "Vis tiek siųsti",
     "Edit message" : "Taisyti laišką",
     "Draft" : "Juodraštis",
     "Message discarded" : "Laiškas atmestas",
@@ -279,7 +278,11 @@ OC.L10N.register(
     "SMTP" : "SMTP",
     "Save Config" : "Įrašyti konfigūraciją",
     "With the settings above, the app will create account settings in the following way:" : "Naudodama aukščiau esančius nustatymus, programėlė sukurs paskyrai nustatymus štai tokiu būdu: ",
-    "Account connected" : "Paskyra prijungta",
+    "E-mail address" : "El. pašto adresas",
+    "Valid until" : "Galioja iki",
+    "Certificate" : "Liudijimas",
+    "Back" : "Atgal",
+    "Submit" : "Pateikti",
     "Keyboard shortcut" : "Spartusis klavišas",
     "Keyboard shortcuts" : "Klaviatūros greitieji klavišai",
     "Speed up your Mail experience with these quick shortcuts." : "Padidinkite savo našumą naudodamiesi šiomis nuorodomis.",
@@ -288,10 +291,11 @@ OC.L10N.register(
     "Older message" : "Senesni laiškai",
     "Toggle star" : "Perjungti laiško žymėjimą, kaip pažymėtą žvaigždute",
     "Toggle unread" : "Perjungti laiško žymėjimą, kaip neskaityto",
+    "Archive" : "Archyvuoti",
     "Refresh" : "Įkelti iš naujo",
+    "Account connected" : "Paskyra prijungta",
     "Connect your mail account" : "Priregistruoti elektroninio pašto paskyrą",
     "All" : "Visos",
-    "Archive" : "Archyvuoti",
     "Drafts" : "Juodraščiai",
     "Favorites" : "Mėgstami",
     "All inboxes" : "Visos pašto dėžutės",
