@@ -44,6 +44,7 @@ OC.L10N.register(
     "Looking up configuration" : "Побарување конфигурација",
     "Checking mail host connectivity" : "Проверка на врската со е-пошта серверот",
     "Configuration discovery failed. Please use the manual settings" : "Неуспешна детекција на конфигурација. Користете рачни поставки",
+    "Password required" : "Потребна е лозинка",
     "Testing authentication" : "Тестирање на автентикација",
     "Account updated" : "Сметката е ажурирана",
     "IMAP server is not reachable" : "IMAP серверот не е достапен",
@@ -54,7 +55,6 @@ OC.L10N.register(
     "SMTP connection failed" : "Неуспешна SMTP врска",
     "There was an error while setting up your account" : "Настана грешка при поставување на вашата сметка",
     "Account settings" : "Праметри за сметката",
-    "Change name" : "Промени име",
     "Signature" : "Потпис",
     "A signature is added to the text of new messages and replies." : "Потписот ќе се додава на крајот од текстот на нови пораки и одговори.",
     "Writing mode" : "Режим на пишување",
@@ -64,6 +64,7 @@ OC.L10N.register(
     "Mail server" : "Сервер за е-пошта",
     "Update alias" : "Ажурирај алијас",
     "Delete alias" : "Избриши алијас",
+    "Change name" : "Промени име",
     "Email address" : "Е-пошта адреси",
     "Add alias" : "Додади псевдоним",
     "Create alias" : "Креирај алијас",
@@ -95,6 +96,7 @@ OC.L10N.register(
     "Discard & close draft" : "Отфрли & затвори примерок",
     "Upload attachment" : "Прикачи прилог",
     "Add attachment from Files" : "Додади прилог од датотеките",
+    "Add link" : "Додади линк",
     "Send later" : "Испрати покасно",
     "Enable formatting" : "Овозможи форматирање",
     "Disable formatting" : "Оневозможи форматирање",
@@ -106,21 +108,9 @@ OC.L10N.register(
     "Monday morning" : "Понеделник наутро",
     "Custom date and time" : "Одреден датум и време",
     "Enter a date" : "Внесете датум",
-    "Uploading attachments …" : "Прикачување на прилог ...",
-    "Sending …" : "Испраќам ...",
-    "Error sending your message" : "Грешка при испраќање на пораката",
-    "Go back" : "Назад",
-    "Retry" : "Обидете се повторно",
-    "Send anyway" : "Испрати секако",
-    "Message will be sent at" : "Пораката ќе биде испратена",
-    "Message sent!" : "Пораката е испратена!",
     "Add share link from {productName} Files" : "Додади линк со споделување од {productName} датотеките",
     "Send" : "Прати",
-    "Encrypt and send" : "Шифрирај и испрати",
-    "Send unencrypted" : "Испрати нешифрирана",
     "Message {id} could not be found" : "Пораката {id} не е пронајдена",
-    "No sent mailbox configured. Please pick one in the account settings." : "Нема сандаче за испратени пораки. Изберете сандаче во параметрите на сметката.",
-    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Се обидувате да испратите до многу примачи во До и/или Cc. Можете да користите Bcc за да ги скриете адресите на примачите.",
     "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Сите постоечки форматирања (како пример: болд, потцртан текст, италик итн.) ќе бидат отстранети.",
     "Turn off formatting" : "Исклучи форматирање",
     "Turn off and remove formatting" : "Исклучи и острани форматирање",
@@ -146,7 +136,6 @@ OC.L10N.register(
     "Unselect" : "Поништи избор",
     "Select" : "Select",
     "Edit tags" : "Удери ознаки",
-    "Move" : "Премести",
     "More actions" : "Повеќе акции",
     "Edit as new message" : "Измени како нова порака",
     "Create event" : "Креирај настан",
@@ -216,6 +205,7 @@ OC.L10N.register(
     "Always show images from {domain}" : "Секогаш прикажувај фотографии од {domain}",
     "Message frame" : "Порака рамка",
     "Quoted text" : "Цитиран текст",
+    "Move" : "Премести",
     "Moving" : "Преместува",
     "Moving message" : "Преместување порака",
     "Mail settings" : "Параметри за е-пошта",
@@ -251,8 +241,16 @@ OC.L10N.register(
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} непрочитана од {total}","{unread} непрочитани од {total}"],
     "Outbox" : "Излезно сандаче",
     "New message" : "Нова порака",
+    "Error sending your message" : "Грешка при испраќање на пораката",
+    "Go back" : "Назад",
+    "Retry" : "Обидете се повторно",
+    "Uploading attachments …" : "Прикачување на прилог ...",
+    "Sending …" : "Испраќам ...",
+    "Send anyway" : "Испрати секако",
     "Edit message" : "Уреди порака",
     "Draft" : "Шаблон",
+    "No sent mailbox configured. Please pick one in the account settings." : "Нема сандаче за испратени пораки. Изберете сандаче во параметрите на сметката.",
+    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Се обидувате да испратите до многу примачи во До и/или Cc. Можете да користите Bcc за да ги скриете адресите на примачите.",
     "Message discarded" : "Пораката е отфрлена",
     "Could not discard message" : "Неможе да се отфрли порака",
     "No message selected" : "Нема избрана порака",
@@ -349,7 +347,11 @@ OC.L10N.register(
     "Save Config" : "Зачувај конфигурација",
     "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% и %EMAIL% ќе биде заменето со корнички ID и e-po[ta",
     "With the settings above, the app will create account settings in the following way:" : "Со овие параметри, апликацијата ќе креира сметки:",
-    "Account connected" : "Сметката е поврзана",
+    "E-mail address" : "Е-пошта адреса",
+    "Valid until" : "Валиден до",
+    "Certificate" : "Сертификат",
+    "Back" : "Назад",
+    "Submit" : "Испрати",
     "Keyboard shortcut" : "Кратенка преку тастатура",
     "Keyboard shortcuts" : "Кратенки преку тастатура",
     "Speed up your Mail experience with these quick shortcuts." : "Забрзајте го вашето искуство со овие брзи кратенки.",
@@ -358,11 +360,12 @@ OC.L10N.register(
     "Older message" : "Постари пораки",
     "Toggle star" : "Вклучи омилени",
     "Toggle unread" : "Вклучи непрочитани",
+    "Archive" : "Архива",
     "Refresh" : "Освежи",
+    "Account connected" : "Сметката е поврзана",
     "Connect your mail account" : "Поврзете ја вашата е-пошта сметка",
     "Itinerary for {type} is not supported yet" : "Итинерар за {type} сеуште не е поддржан",
     "All" : "Сите",
-    "Archive" : "Архива",
     "Drafts" : "Шаблони",
     "Favorites" : "Омилени",
     "Priority inbox" : "Приоритетно сандаче",
