@@ -40,8 +40,8 @@ OC.L10N.register(
     "Sign in with Google" : "Inloggen met Google",
     "Save" : "Bewaren",
     "Connect" : "Verbinden",
+    "Password required" : "Wachtwoord vereist",
     "Account settings" : "Accountinstellingen",
-    "Change name" : "Naam veranderen",
     "Signature" : "Handtekening",
     "A signature is added to the text of new messages and replies." : "Een handtekening wordt toegevoegd aan de tekst van nieuwe berichten en antwoorden.",
     "Writing mode" : "Schrijfmodus",
@@ -54,6 +54,7 @@ OC.L10N.register(
     "Update alias" : "Bijwerken alias",
     "Show update alias form" : "Toon formulier Bijwerken alias",
     "Delete alias" : "Verwijderen alias",
+    "Change name" : "Naam veranderen",
     "Email address" : "E-mailadres",
     "Add alias" : "Voeg bijnaam toe",
     "Create alias" : "Aanmaken alias",
@@ -83,25 +84,14 @@ OC.L10N.register(
     "Discard & close draft" : "Verwijderen & concept sluiten",
     "Upload attachment" : "Bijlage uploaden",
     "Add attachment from Files" : "Bijlage toevoegen vanuit Bestanden",
+    "Add link" : "Voeg link toe",
     "Enable formatting" : "Inschakelen formattering",
     "Request a read receipt" : "Vraag een leesbevestiging",
     "Encrypt message with Mailvelope" : "Versleutel bericht met Mailvelope",
     "Enter a date" : "Voeg een datum toe",
-    "Uploading attachments …" : "Bijlage aan het uploaden ...",
-    "Sending …" : "Versturen ...",
-    "Error sending your message" : "Fout bij het versturen van jouw bericht",
-    "Go back" : "Ga terug",
-    "Retry" : "Opnieuw proberen",
-    "Warning sending your message" : "Waarschuwing bij het versturen van jouw bericht",
-    "Send anyway" : "Toch verzenden",
-    "Message sent!" : "Bericht verzonden!",
     "Add share link from {productName} Files" : "Toevoegen deellink van {productName} Bestanden",
     "Send" : "Versturen",
-    "Encrypt and send" : "Versleutelen en versturen",
-    "Send unencrypted" : "Verstuur onversleuteld",
     "Message {id} could not be found" : "Bericht {id} kon niet worden gevonden",
-    "No sent mailbox configured. Please pick one in the account settings." : "Er is geen map voor verzonden berichten ingesteld. Kies er een in de accountinstellingen.",
-    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Je probeert een e-mail te versturen met veel ontvangers in Aan en /of Cc. Overweeg om Bcc te gebruiken om de adressen van de ontvangers voor elkaar te verbergen.",
     "Choose a file to add as attachment" : "Kies een bestand om als bijlage toe te voegen",
     "Choose a file to share as a link" : "Kies een bestand om als link te delen",
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["De bijlage overschrijdt de toegestane omvang van {size}. Deel de bestanden in plaats daarvan via een link.","De bijlagen overschrijden de toegestane omvang van {size}. Deel de bestanden in plaats daarvan via een link."],
@@ -122,7 +112,6 @@ OC.L10N.register(
     "Unselect" : "Deselecteren",
     "Select" : "Selecteer",
     "Edit tags" : "Bewerken tags",
-    "Move" : "Verplaatsen",
     "Move thread" : "Verplaats draadje",
     "Delete thread" : "Verwijder draadje",
     "More actions" : "Meer acties",
@@ -189,6 +178,7 @@ OC.L10N.register(
     "Always show images from {domain}" : "Afbeeldingen van {domain} altijd tonen",
     "Message frame" : "Berichtenkader",
     "Quoted text" : "Geciteerde tekst",
+    "Move" : "Verplaatsen",
     "Moving" : "Verplaatsen",
     "Moving thread" : "Verplaatsen draadje",
     "Moving message" : "Verplaatsen bericht",
@@ -224,7 +214,16 @@ OC.L10N.register(
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} ongelezen van de {total}","{unread} ongelezen van de {total}"],
     "Outbox" : "Uitbak",
     "New message" : "Nieuw bericht",
+    "Error sending your message" : "Fout bij het versturen van jouw bericht",
+    "Go back" : "Ga terug",
+    "Retry" : "Opnieuw proberen",
+    "Uploading attachments …" : "Bijlage aan het uploaden ...",
+    "Sending …" : "Versturen ...",
+    "Warning sending your message" : "Waarschuwing bij het versturen van jouw bericht",
+    "Send anyway" : "Toch verzenden",
     "Draft" : "Concept",
+    "No sent mailbox configured. Please pick one in the account settings." : "Er is geen map voor verzonden berichten ingesteld. Kies er een in de accountinstellingen.",
+    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Je probeert een e-mail te versturen met veel ontvangers in Aan en /of Cc. Overweeg om Bcc te gebruiken om de adressen van de ontvangers voor elkaar te verbergen.",
     "No message selected" : "Geen bericht geselecteerd",
     "Message" : "Bericht",
     "Oh Snap!" : "O nee!",
@@ -349,7 +348,11 @@ OC.L10N.register(
     "Unprovision & Delete Config" : "De-provision & verwijder config",
     "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% en %EMAIL% zal worden vervangen door de gebruikers UID en e-mail",
     "With the settings above, the app will create account settings in the following way:" : "Met de bovenstaande instellingen maakt de app op de volgende manier accountinstellingen:",
-    "Account connected" : "Account verbonden",
+    "E-mail address" : "E-mailadres",
+    "Valid until" : "Geldig tot",
+    "Certificate" : "Certificaat",
+    "Back" : "Terug",
+    "Submit" : "Verwerken",
     "Keyboard shortcut" : "Sneltoets",
     "Keyboard shortcuts" : "Sneltoetsen",
     "Speed up your Mail experience with these quick shortcuts." : "Versnel je e-mailervaring met deze handige snelkoppelingen.",
@@ -358,11 +361,12 @@ OC.L10N.register(
     "Older message" : "Ouder bericht",
     "Toggle star" : "Omschakelen ster",
     "Toggle unread" : "Omschakelen ongelezen",
+    "Archive" : "Archiveer",
     "Refresh" : "Verversen",
+    "Account connected" : "Account verbonden",
     "Connect your mail account" : "Verbind je e-mailaccount",
     "Itinerary for {type} is not supported yet" : "route voor {type} wordt nog niet ondersteund",
     "All" : "Alle",
-    "Archive" : "Archiveer",
     "Drafts" : "Concepten",
     "Favorites" : "Favorieten",
     "Priority inbox" : "Prioriteit",
