@@ -12,18 +12,18 @@ OC.L10N.register(
     "Connect" : "Kopla til",
     "Signature" : "Signatur",
     "Cancel" : "Avbryt",
-    "Retry" : "Forsøk att",
     "Send" : "Send",
     "Favorite" : "Favoritt",
     "Select" : "Vel",
-    "Move" : "Move",
     "Create" : "Lag",
     "Comment" : "Kommentér",
     "Choose" : "Vel",
     "Other" : "Anna",
     "Reply" : "Svare",
+    "Move" : "Move",
     "Quota" : "Kvote",
     "Saving" : "Lagrar",
+    "Retry" : "Forsøk att",
     "Delete" : "Ta bort",
     "Add" : "Legg til",
     "Tags" : "Emneord",
@@ -37,6 +37,8 @@ OC.L10N.register(
     "User" : "Bruker",
     "Host" : "Tenar",
     "Port" : "Port",
+    "Certificate" : "Sertifikat",
+    "Back" : "Tilbake",
     "Keyboard shortcuts" : "Tastatursnarvegar",
     "Refresh" : "Last inn på nytt",
     "All" : "Alle",
