@@ -20,6 +20,7 @@ OC.L10N.register(
     "Connecting" : "Connexion",
     "Save" : "Salvar",
     "Connect" : "Connectar",
+    "Password required" : "Senhal requerit",
     "Account settings" : "Paramètres de compte",
     "Signature" : "Signatura",
     "Mail server" : "Servidor email",
@@ -27,18 +28,14 @@ OC.L10N.register(
     "Cancel" : "Anullar",
     "From" : "De",
     "Write message …" : "Escriure un messatge…",
+    "Add link" : "Apondre un ligam",
     "Monday morning" : "Diluns matin",
-    "Sending …" : "Mandadís…",
-    "Go back" : "Revenir en arrière",
-    "Retry" : "Tornar ensajar",
-    "Message sent!" : "Messatge mandat !",
     "Send" : "Mandar",
     "Choose a file to add as attachment" : "Causissètz un fichièr de jónher al messatge",
     "No message found yet" : "Pas cap de messatge trobat",
     "Favorite" : "Favorit",
     "Read" : "Legit",
     "Select" : "Select",
-    "Move" : "Move",
     "More actions" : "Mai d’accions",
     "All day" : "Tota la jornada",
     "Create" : "Crear",
@@ -49,12 +46,16 @@ OC.L10N.register(
     "Other" : "Autre",
     "Reply" : "Respondre",
     "Choose a folder to store the attachment in" : "Causissètz lo dorsièr dins lo qual enregistrar la pèça junta",
+    "Move" : "Move",
     "Quota" : "Quota",
     "Loading …" : "Cargament…",
     "Mark all as read" : "Marcar totes coma legits",
     "Edit name" : "Modificar lo nom",
     "Clear cache" : "Voidar l'escondedor",
     "_{total} message_::_{total} messages_" : ["{total} messatge","{total} messatges"],
+    "Go back" : "Revenir en arrière",
+    "Retry" : "Tornar ensajar",
+    "Sending …" : "Mandadís…",
     "Delete" : "Suprimir",
     "Copy to clipboard" : "Copiar dins lo quichapapièrs",
     "Add" : "Apondre",
@@ -76,12 +77,16 @@ OC.L10N.register(
     "User" : "User",
     "Host" : "Òste",
     "Port" : "Pòrt",
-    "Account connected" : "Compte connectat",
+    "Valid until" : "Valid fins a",
+    "Certificate" : "Certificat",
+    "Back" : "Retorn",
+    "Submit" : "Transmetre",
     "Keyboard shortcut" : "Acorchis de clavièr",
     "Keyboard shortcuts" : "Acorchis de clavièr",
-    "Refresh" : "Refrescar",
-    "All" : "Tot",
     "Archive" : "Archius",
+    "Refresh" : "Refrescar",
+    "Account connected" : "Compte connectat",
+    "All" : "Tot",
     "Drafts" : "Borrolhons",
     "Favorites" : "Favorits",
     "All inboxes" : "Totas las bóstias",
