@@ -40,15 +40,15 @@ OC.L10N.register(
     "Connecting" : "Se conectează",
     "Save" : "Salvează",
     "Connect" : "Conectare",
+    "Password required" : "Parola este necesară",
     "Account settings" : "Setări cont",
-    "Change name" : "Schimbă numele",
     "Signature" : "Semnătură",
     "A signature is added to the text of new messages and replies." : "O semnătură a fost adăugată la noile mesaje trimise și la răspunsuri.",
     "Writing mode" : "Mod de scriere",
     "Preferred writing mode for new messages and replies." : "Modul de scriere preferat pentru mesajele și răspunsurile noi.",
     "Default folders" : "Dosare implicite",
-    "The folders to use for drafts, sent messages and deleted messages." : "Dosarele utilizate pentru mesajele nefinalizate, mesajele trimise și mesajele șterse.",
     "Mail server" : "Server mail",
+    "Change name" : "Schimbă numele",
     "Cancel" : "Anulează",
     "Add mail account" : "Adaugă un cont de mail",
     "Show keyboard shortcuts" : "Arată scurtături",
@@ -69,6 +69,7 @@ OC.L10N.register(
     "Discard & close draft" : "Renunță și închide mesajul",
     "Upload attachment" : "Încarcă atașament",
     "Add attachment from Files" : "Atașează din Fișiere",
+    "Add link" : "Adaugă link",
     "Send later" : "Trimite mai târziu",
     "Enable formatting" : "Permite formatarea",
     "Encrypt message with Mailvelope" : "Criptează mesajul cu Mailvelope",
@@ -78,11 +79,6 @@ OC.L10N.register(
     "Monday morning" : "Luni dimineață",
     "Custom date and time" : "Dată și oră personalizate",
     "Enter a date" : "Introdu data",
-    "Uploading attachments …" : "Încarcă atașamentele ...",
-    "Sending …" : "Se trimite...",
-    "Go back" : "Înapoi",
-    "Retry" : "Reîncearcă",
-    "Message sent!" : "Mesaj trimis!",
     "Send" : "Trimite",
     "Favorite" : "Favorite",
     "Unread" : "Necitit",
@@ -93,7 +89,6 @@ OC.L10N.register(
     "Unselect" : "Deselectează",
     "Select" : "Select",
     "Edit tags" : "Modifică tag-urile",
-    "Move" : "Mută",
     "More actions" : "Mai multe acțiuni",
     "Edit as new message" : "Editează ca mesaj nou",
     "Create event" : "Creează eveniment",
@@ -108,6 +103,7 @@ OC.L10N.register(
     "Reply" : "Răspunde",
     "Unnamed" : "Fără nume",
     "Choose a folder to store the attachment in" : "Alege un dosar în care să stochez atașamentul",
+    "Move" : "Mută",
     "Quota" : "Procent",
     "Saving" : "Se salvează",
     "Remove account" : "Sterge contul",
@@ -115,8 +111,17 @@ OC.L10N.register(
     "Mark all as read" : "Marcaţi tot ca fiind citit",
     "Edit name" : "Modifică numele",
     "Clear cache" : "Șterge cache",
+    "Go back" : "Înapoi",
+    "Retry" : "Reîncearcă",
+    "Uploading attachments …" : "Încarcă atașamentele ...",
+    "Sending …" : "Se trimite...",
     "Delete" : "Șterge",
+    "Copy to clipboard" : "Copiază în clipboard",
     "Add" : "Adaugă",
+    "Tags" : "Etichete",
+    "Clear" : "Șterge ",
+    "Search" : "Caută",
+    "Date" : "Date",
     "Disabled" : "Dezactivați",
     "Enabled" : "Activat",
     "Custom" : "Particularizat",
@@ -129,16 +134,22 @@ OC.L10N.register(
     "(organizer)" : "(organizator)",
     "Untitled event" : "Eveniment fără titlu",
     "Reset" : "Resetare",
+    "Client ID" : "ID client",
+    "Client secret" : "Secret client",
     "General" : "General",
     "User" : "Utilizator",
     "Host" : "Gazdă",
     "Port" : "Portul",
+    "Valid until" : "Valabil până la",
+    "Certificate" : "Certificat",
+    "Back" : "Înapoi",
+    "Submit" : "Trimite",
     "Keyboard shortcut" : "Scurtături din tastatură",
     "Keyboard shortcuts" : "Scurtături din tastatură",
-    "Search" : "Caută",
-    "Refresh" : "Reîmprospătează",
-    "All" : "Toate ",
     "Archive" : "Arhivă",
+    "Refresh" : "Reîmprospătează",
+    "Account connected" : "Cont conectat",
+    "All" : "Toate ",
     "Drafts" : "Schițe",
     "Favorites" : "Favorite",
     "Sent" : "Trimis",
