@@ -37,7 +37,6 @@ OC.L10N.register(
     "Save" : "Sarva",
     "Connect" : "Connete",
     "Account settings" : "Impostatziones de contu",
-    "Change name" : "Càmbia nùmene",
     "Signature" : "Firma",
     "A signature is added to the text of new messages and replies." : "S'agiunghet una firma a su testu de is messàgios noos e de is respostas.",
     "Writing mode" : "Modalidade de iscritura",
@@ -50,6 +49,7 @@ OC.L10N.register(
     "Update alias" : "Agiorna identidade",
     "Show update alias form" : "Mustra s'agiornamentu de sa forma de su identidade",
     "Delete alias" : "Cantzella identidade",
+    "Change name" : "Càmbia nùmene",
     "Email address" : "Indiritzu de posta eletrònica",
     "Add alias" : "Agiunghe identidade",
     "Create alias" : "Crea identidade",
@@ -78,25 +78,14 @@ OC.L10N.register(
     "Draft saved" : "Brutacòpia sarvada",
     "Upload attachment" : "Càrriga alligongiadu",
     "Add attachment from Files" : "Agiunghe alligongiadu dae Archìvios",
+    "Add link" : "Agiunghe ligòngiu",
     "Enable formatting" : "Ativa formatatzione",
     "Request a read receipt" : "Pedi una cunfirma de letura",
     "Encrypt message with Mailvelope" : "Tzifra messàgiu cun Mailvelope",
     "Enter a date" : "Inserta una data",
-    "Uploading attachments …" : "Carrighende alligongiadu ...",
-    "Sending …" : "Imbiende ...",
-    "Error sending your message" : "Errore in s'imbiu de su messàgiu",
-    "Go back" : "Bae in segus",
-    "Retry" : "Torra a proare",
-    "Warning sending your message" : "Avisu in s'imbiu de su messàgiu",
-    "Send anyway" : "Imbia a su pròpiu",
-    "Message sent!" : "Messàgiu imbiadu!",
     "Add share link from {productName} Files" : "Agiunghe unu ligòngiu de cumpartzidura dae {productName} Archìvios",
     "Send" : "Imbia",
-    "Encrypt and send" : "Tzifra e imbia",
-    "Send unencrypted" : "Imbia chene tzifrare",
     "Message {id} could not be found" : "Su messàgiu {id} no s'est pòdidu agatare",
-    "No sent mailbox configured. Please pick one in the account settings." : "Peruna casella de posta imbiada cunfigurada. Sèbera•nde una in is impostatziones de su contu.",
-    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Ses proende a imbiare a tropu persones in A e/o Cc. Cunsìdera de impreare Bcc pro cuare is indiritzos de is chi retzint.",
     "Choose a file to add as attachment" : "Sèbera un'archìviu de agiùnghere comente alligongiadu",
     "Choose a file to share as a link" : "Sèbera un'archìviu de cumpartzire comente ligòngiu",
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Is alligongiados propassant sa mannària permìtida de {size}. Cumpartzi is archìvios cun unu ligòngiu.","Is alligongiados propassant sa mannària permìtida de {size}. Cumpartzi is archìvios cun unu ligòngiu."],
@@ -115,7 +104,6 @@ OC.L10N.register(
     "Unselect" : "Deseletziona",
     "Select" : "Seletziona",
     "Edit tags" : "Modìfica etichetas",
-    "Move" : "Tràmuda",
     "Move thread" : "Tràmuda dibata",
     "Delete thread" : "Cantzella dibata",
     "More actions" : "Àteras atziones",
@@ -178,6 +166,7 @@ OC.L10N.register(
     "Always show images from {domain}" : "Mustra semper imàgines dae {domain}",
     "Message frame" : "Ricuadru de se messàgiu",
     "Quoted text" : "Testu tzitadu",
+    "Move" : "Tràmuda",
     "Moving" : "Tramudende",
     "Moving thread" : "Tramudende sa dibata",
     "Moving message" : "Tramudende su messàgiu",
@@ -212,6 +201,15 @@ OC.L10N.register(
     "_{total} message_::_{total} messages_" : ["{total} messàgios","{total} messàgios"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} non lèghidos de {total}","{unread} unread of {total}"],
     "New message" : "Messàgiu nou",
+    "Error sending your message" : "Errore in s'imbiu de su messàgiu",
+    "Go back" : "Bae in segus",
+    "Retry" : "Torra a proare",
+    "Uploading attachments …" : "Carrighende alligongiadu ...",
+    "Sending …" : "Imbiende ...",
+    "Warning sending your message" : "Avisu in s'imbiu de su messàgiu",
+    "Send anyway" : "Imbia a su pròpiu",
+    "No sent mailbox configured. Please pick one in the account settings." : "Peruna casella de posta imbiada cunfigurada. Sèbera•nde una in is impostatziones de su contu.",
+    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Ses proende a imbiare a tropu persones in A e/o Cc. Cunsìdera de impreare Bcc pro cuare is indiritzos de is chi retzint.",
     "No message selected" : "Perunu messàgiu seletzionadu",
     "Message" : "Messàgiu",
     "Oh Snap!" : "Lampu!",
@@ -314,7 +312,10 @@ OC.L10N.register(
     "Save Config" : "Sarva cunfiguratzione",
     "Unprovision & Delete Config" : "Boga•nche sa frunidura e Cantzella Cunfiguratzione",
     "With the settings above, the app will create account settings in the following way:" : "Cun is impostatziones de antis, s'aplicatzione at a creare is impostatziones de contu in custa manera:",
-    "Account connected" : "Contu collegadu",
+    "E-mail address" : "Indiritzu de posta eletrònica",
+    "Certificate" : "Tzertificadu",
+    "Back" : "In segus",
+    "Submit" : "Imbia",
     "Keyboard shortcut" : "Curtziadòrgiu de tecladu",
     "Keyboard shortcuts" : "Curtziadòrgios de tecladu",
     "Speed up your Mail experience with these quick shortcuts." : "Faghe s'esperièntzia de Mail prus lestra cun custos curtziadòrgios.",
@@ -323,11 +324,12 @@ OC.L10N.register(
     "Older message" : "Messàgiu prus betzu",
     "Toggle star" : "Ativa/disativa s'istella",
     "Toggle unread" : "Ativa/disativa non lèghidu",
+    "Archive" : "Cartella",
     "Refresh" : "Agiorna",
+    "Account connected" : "Contu collegadu",
     "Connect your mail account" : "Connete·ti a su contu de posta tuo",
     "Itinerary for {type} is not supported yet" : "S'itineràriu pro {type} no est ancora suportadu",
     "All" : "Totu",
-    "Archive" : "Cartella",
     "Drafts" : "Brutacòpias",
     "Favorites" : "Preferidos",
     "Priority inbox" : "Posta retzida cun prioridade",
