@@ -23,6 +23,7 @@ OC.L10N.register(
     "Connecting" : "Duke u lidhur",
     "Save" : "Ruaj",
     "Connect" : "Lidhu",
+    "Password required" : "Kërkohet fjalëkalimi",
     "Signature" : "Nënshkrimi",
     "Cancel" : "Anullo",
     "Add mail account" : "Shto llogarinë e postës elektronike",
@@ -30,10 +31,7 @@ OC.L10N.register(
     "Subject" : "Temë",
     "Upload attachment" : "Ngarko bashkëngjitje",
     "Add attachment from Files" : "Shto bashkëlidhje nga Dosjet",
-    "Sending …" : "Po dërgohet …",
-    "Go back" : "Shko prapa",
-    "Retry" : "Riprovoni",
-    "Message sent!" : "Mesazhi u dërgua!",
+    "Add link" : "Shto link",
     "Send" : "Dërgo",
     "Choose a file to add as attachment" : "Zgjidhni një kartelë që të shtohet si bashkëngjitje",
     "Unfavorite" : "Jo i/e preferuar",
@@ -41,7 +39,6 @@ OC.L10N.register(
     "Read" : "Lexoni",
     "Select" : "Zgjidhni",
     "Edit tags" : "Përpunoni etiketa",
-    "Move" : "Zhvendos",
     "More actions" : "Më tepër veprime ",
     "Forward" : "Përpara",
     "All day" : "Gjithë ditën",
@@ -59,12 +56,16 @@ OC.L10N.register(
     "Choose a folder to store the attachment in" : "Zgjidhni një dosje ku të depozitohet bashkëngjitja",
     "Save all to Files" : "Ruaji të gjitha te Dosjet",
     "The images have been blocked to protect your privacy." : "Imazhet janë bllokuar për të mbrojtur privatësinë tuaj.",
+    "Move" : "Zhvendos",
     "Quota" : "Kuotë",
     "Saving" : "Duke u ruajtur!",
     "Remove account" : "Fshij llogarinë",
     "Mark all as read" : "Shënoji krejt si të lexuar",
     "Clear cache" : "Pastroje fshehtinën",
     "New message" : "Mesazh i ri",
+    "Go back" : "Shko prapa",
+    "Retry" : "Riprovoni",
+    "Sending …" : "Po dërgohet …",
     "Message" : "Mesazh",
     "Delete" : "Fshij",
     "Copy to clipboard" : "Kopjo në dërrasë ",
@@ -90,6 +91,10 @@ OC.L10N.register(
     "User" : "Përdorues",
     "Host" : "Strehë",
     "Port" : "Porta",
+    "Valid until" : "E vlefshme deri më",
+    "Certificate" : "Çertifikata",
+    "Back" : "Prapa",
+    "Submit" : "Dërgo",
     "Keyboard shortcut" : "Shkurtore tastiere",
     "Keyboard shortcuts" : "Shkurtoret e tastierës",
     "Speed up your Mail experience with these quick shortcuts." : "Përmirësoni përvojën tuaj në Mail me këto shkurtore të shpejta.",
@@ -97,10 +102,10 @@ OC.L10N.register(
     "Older message" : "Mesazhe më të vjetra",
     "Toggle star" : "Toggle star",
     "Toggle unread" : "Toggle i pa lexuar",
+    "Archive" : "Arkiva",
     "Refresh" : "Rifresko",
     "Connect your mail account" : "Lidhni llogarinë tuaj të postës elektronike",
     "All" : "Të gjithë",
-    "Archive" : "Arkiva",
     "Drafts" : "Skica",
     "Favorites" : "Favorites",
     "All inboxes" : "Krejt kutitë e postës",
