@@ -33,13 +33,14 @@ OC.L10N.register(
     "Connecting" : "Повезујем се",
     "Save" : "Сачувај",
     "Connect" : "Повежи се",
+    "Password required" : "Потребна је лозинка",
     "Account settings" : "Поставке налога",
-    "Change name" : "Промени име",
     "Signature" : "Потпис",
     "A signature is added to the text of new messages and replies." : "Потпис је додат на текст свих нових порука и одговора.",
     "Writing mode" : "Режим писања",
     "Preferred writing mode for new messages and replies." : "Жељени режим писања за нове поруке и одговоре.",
     "Mail server" : "Сервер е-поште",
+    "Change name" : "Промени име",
     "Email address" : "Адреса е-поште",
     "Add alias" : "Додајте алиас",
     "Cancel" : "Поништи",
@@ -64,21 +65,14 @@ OC.L10N.register(
     "Draft saved" : "Нацрт сачуван",
     "Upload attachment" : "Закачи прилог",
     "Add attachment from Files" : "Додај прилог из фајлова",
+    "Add link" : "Додај везу",
     "Enable formatting" : "Укључи форматирање",
     "Encrypt message with Mailvelope" : "Шифруј поруку са Mailvelope-ом",
     "Tomorrow morning" : "Сутра ујутру",
     "Tomorrow afternoon" : "Сутра после подне",
     "Monday morning" : "Понедељак ујутру",
     "Enter a date" : "Унеси датум",
-    "Uploading attachments …" : "Отпремам прилоге …",
-    "Sending …" : "Шаљем …",
-    "Error sending your message" : "Грешка приликом слања поруке",
-    "Go back" : "Иди назад",
-    "Retry" : "Покушај поново",
-    "Message sent!" : "Порука послата!",
     "Send" : "Пошаљи",
-    "Encrypt and send" : "Шифруј и пошаљи",
-    "Send unencrypted" : "Пошаљи нешифровано",
     "Choose a file to add as attachment" : "Изаберите фајл за прилог",
     "Choose a file to share as a link" : "Одаберите фајл који желите да поделите као везу",
     "No message found yet" : "Још нема порука",
@@ -95,7 +89,6 @@ OC.L10N.register(
     "Unselect" : "Уклони избор",
     "Select" : "Обележи",
     "Edit tags" : "Уреди ознаке",
-    "Move" : "Помери",
     "More actions" : "Још акција",
     "Blind copy recipients only" : "Само примаоци невидљиве копије",
     "Forward" : "Проследи",
@@ -131,6 +124,7 @@ OC.L10N.register(
     "Show images" : "Прикажи слике",
     "Message frame" : "Оквир поруке",
     "Quoted text" : "Цитирани текст",
+    "Move" : "Помери",
     "Moving" : "Померам",
     "Quota" : "Квота",
     "Saving" : "Чувам",
@@ -154,6 +148,11 @@ OC.L10N.register(
     "_{total} message_::_{total} messages_" : ["{total} порука","{total} поруке","{total} порука"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} непрочитана од {total}","{unread} непрочитане од {total}","{unread} непрочитаних од {total}"],
     "New message" : "Нова порука",
+    "Error sending your message" : "Грешка приликом слања поруке",
+    "Go back" : "Иди назад",
+    "Retry" : "Покушај поново",
+    "Uploading attachments …" : "Отпремам прилоге …",
+    "Sending …" : "Шаљем …",
     "No message selected" : "Није одабрана ниједна порука",
     "Message" : "Порука",
     "Delete" : "Избриши",
@@ -203,7 +202,11 @@ OC.L10N.register(
     "Port" : "Порт",
     "SMTP" : "SMTP",
     "With the settings above, the app will create account settings in the following way:" : "Уз поставке изнад, апликација ће креирати поставке налога на следећи начин:",
-    "Account connected" : "Налог повезан",
+    "E-mail address" : "Адреса е-поште",
+    "Valid until" : "Важи до",
+    "Certificate" : "Сертификат",
+    "Back" : "Назад",
+    "Submit" : "Пошаљи",
     "Keyboard shortcut" : "Пречица тастатуре",
     "Keyboard shortcuts" : "Пречице на тастатури",
     "Speed up your Mail experience with these quick shortcuts." : "Убрзајте рад са Поштом са овим брзим пречицама.",
@@ -212,11 +215,12 @@ OC.L10N.register(
     "Older message" : "Старије поруке",
     "Toggle star" : "Мењај озвезданост",
     "Toggle unread" : "Означи као прочитано/непрочитано",
+    "Archive" : "Архива",
     "Refresh" : "Освежи",
+    "Account connected" : "Налог повезан",
     "Connect your mail account" : "Повежи се на налог е-поште",
     "Itinerary for {type} is not supported yet" : "Итеринер за {type} још није подржан",
     "All" : "Све",
-    "Archive" : "Архива",
     "Drafts" : "Недовршене",
     "Favorites" : "Омиљене",
     "Priority inbox" : "Приоритетно сандуче",
