@@ -32,8 +32,8 @@ OC.L10N.register(
     "SMTP Password" : "Mật khẩu SMTP",
     "Save" : "Lưu",
     "Connect" : "Kết nối",
+    "Password required" : "Mật khẩu đã được yêu cầu",
     "Account settings" : "Cài đặt tài khoản",
-    "Change name" : "Đổi tên",
     "Signature" : "Chữ ký",
     "A signature is added to the text of new messages and replies." : "Chữ ký được thêm vào tin nhắn và thư trả lời mới.",
     "Writing mode" : "Chế độ soạn thảo",
@@ -43,6 +43,7 @@ OC.L10N.register(
     "Trusted senders" : "Người gửi đáng tin cậy",
     "Mail server" : "Máy chủ thư",
     "Sieve filter server" : "Máy chủ lọc Sieve",
+    "Change name" : "Đổi tên",
     "Email address" : "Địa chỉ thư điện tử",
     "Add alias" : "Thêm bí danh",
     "Cancel" : "Hủy bỏ",
@@ -66,21 +67,13 @@ OC.L10N.register(
     "Draft saved" : "Bản nháp đã được lưu",
     "Upload attachment" : "Tải lên một đính kèm",
     "Add attachment from Files" : "Thêm tệp đính kèm từ Tệp",
+    "Add link" : "Thêm đường dẫn",
     "Enable formatting" : "Bật định dạng",
     "Request a read receipt" : "Yêu cầu xác nhận đã đọc",
     "Encrypt message with Mailvelope" : "Mã hóa thư bằng Mailvelope",
-    "Uploading attachments …" : "Đang tải lên các tệp đính kèm …",
-    "Sending …" : "Đang gửi …",
-    "Error sending your message" : "Lỗi khi gửi tin nhắn",
-    "Go back" : "Quay lại",
-    "Retry" : "Thử lại",
-    "Message sent!" : "Đã gửi tin nhắn!",
     "Add share link from {productName} Files" : "Thêm liên kết chia sẻ từ Tệp {productName}",
     "Send" : "Gởi",
-    "Encrypt and send" : "Mã hóa và gửi",
-    "Send unencrypted" : "Gửi không mã hóa",
     "Message {id} could not be found" : "Không tìm thấy tin nhắn {id}",
-    "No sent mailbox configured. Please pick one in the account settings." : "Không có hộp thư đã gửi nào được định cấu hình. Vui lòng chọn một trong cài đặt tài khoản.",
     "Choose a file to add as attachment" : "Chọn một tệp để thêm dưới dạng tệp đính kèm",
     "Choose a file to share as a link" : "Chọn một tệp để chia sẻ dưới dạng liên kết",
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Các tệp đính kèm vượt quá kích thước được cho phép là {size}. Thay vào đó, hãy chia sẻ các tệp qua liên kết."],
@@ -96,7 +89,6 @@ OC.L10N.register(
     "Unselect" : "Bỏ chọn",
     "Select" : "Select",
     "Edit tags" : "Sửa thẻ",
-    "Move" : "Dịch chuyển",
     "More actions" : "Nhiều hành động hơn",
     "Edit as new message" : "Chỉnh sửa dưới dạng tin nhắn mới",
     "Create event" : "Tạo sự kiện mới",
@@ -117,6 +109,7 @@ OC.L10N.register(
     "Could not create event" : "Không thể tạo sự kiện",
     "Comment" : "Bình luận",
     "Accept" : "Đồng ý",
+    "Decline" : "Từ chối",
     "Could not open mailbox" : "Không thể mở hộp thư",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Lập chỉ mục tin nhắn của bạn. Quá trình này có thể lâu hơn một chút đối với các hộp thư lớn.",
     "Choose target mailbox" : "Chọn hộp thư mục tiêu",
@@ -151,6 +144,7 @@ OC.L10N.register(
     "Always show images from {domain}" : "Luôn hiển thị hình ảnh từ {domain}",
     "Message frame" : "Khung tin nhắn",
     "Quoted text" : "Văn bản được trích dẫn",
+    "Move" : "Dịch chuyển",
     "Moving" : "Di chuyển",
     "Quota" : "Hạn ngạch",
     "Show only subscribed mailboxes" : "Chỉ hiển thị các hộp thư đã đăng ký",
@@ -183,6 +177,12 @@ OC.L10N.register(
     "_{total} message_::_{total} messages_" : ["{total} tin nhắn"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} thư chưa đọc trong tổng số {total} thư"],
     "New message" : "Tin nhắn mới",
+    "Error sending your message" : "Lỗi khi gửi tin nhắn",
+    "Go back" : "Quay lại",
+    "Retry" : "Thử lại",
+    "Uploading attachments …" : "Đang tải lên các tệp đính kèm …",
+    "Sending …" : "Đang gửi …",
+    "No sent mailbox configured. Please pick one in the account settings." : "Không có hộp thư đã gửi nào được định cấu hình. Vui lòng chọn một trong cài đặt tài khoản.",
     "No message selected" : "Không có tin nhắn nào được chọn",
     "Delete" : "Xóa",
     "Contacts with this address" : "Liên hệ với địa chỉ này",
@@ -246,6 +246,11 @@ OC.L10N.register(
     "Port" : "Cổng",
     "Enable sieve integration" : "Bật tích hợp sieve",
     "With the settings above, the app will create account settings in the following way:" : "Với cài đặt ở trên, ứng dụng sẽ tạo cài đặt tài khoản theo cách sau:",
+    "E-mail address" : "Địa chỉ email",
+    "Valid until" : "Có hiệu lực đến",
+    "Certificate" : "Chứng chỉ",
+    "Back" : "Quay lại",
+    "Submit" : "Gửi đi",
     "Keyboard shortcut" : "Phím tắt",
     "Keyboard shortcuts" : "Phím tắt",
     "Speed up your Mail experience with these quick shortcuts." : "Tăng tốc trải nghiệm Thư của bạn với các phím tắt nhanh này.",
@@ -254,11 +259,12 @@ OC.L10N.register(
     "Older message" : "Tin nhắn cũ hơn",
     "Toggle star" : "Chuyển đổi dấu sao",
     "Toggle unread" : "Chuyển đổi chưa đọc",
+    "Archive" : "Lưu trữ",
     "Refresh" : "Làm mới",
+    "Account connected" : "Tài khoản đã được kết nối",
     "Connect your mail account" : "Kết nối tài khoản thư của bạn",
     "Itinerary for {type} is not supported yet" : "Hành trình cho {type} chưa được hỗ trợ",
     "All" : "Tất cả",
-    "Archive" : "Lưu trữ",
     "Drafts" : "Bản nháp",
     "Favorites" : "Ưa thích",
     "Priority inbox" : "Hộp thư ưu tiên",
