@@ -49,6 +49,7 @@ OC.L10N.register(
     "Looking up configuration" : "查找配置",
     "Checking mail host connectivity" : "檢查郵件主機連接",
     "Configuration discovery failed. Please use the manual settings" : "配置發現失敗。 請使用手動設置",
+    "Password required" : "請輸入密碼",
     "Testing authentication" : "測試認證",
     "Awaiting user consent" : "等待用戶同意",
     "Account created. Please follow the popup instructions to link your Google account" : "賬戶已創建。請按照彈出說明連結您的 Google 賬戶",
@@ -61,10 +62,9 @@ OC.L10N.register(
     "SMTP username or password is wrong" : "SMTP 用戶名或密碼錯誤",
     "IMAP connection failed" : "IMAP 連線失敗",
     "SMTP connection failed" : "SMTP 連線失敗",
-    "Google authorization popup closed" : "Google 授權彈窗關閉",
+    "Authorization pop-up closed" : "已關閉授權彈跳視窗",
     "There was an error while setting up your account" : "設置您的帳戶時出錯。 ",
     "Account settings" : "賬號設定",
-    "Change name" : "更改名稱",
     "Signature" : "簽名",
     "A signature is added to the text of new messages and replies." : "對新信件與回覆信件內容已附加一個簽名檔",
     "Writing mode" : "書寫模式",
@@ -78,9 +78,13 @@ OC.L10N.register(
     "Trusted senders" : "受信任的寄件人",
     "Mail server" : "郵件伺服器",
     "Sieve filter server" : "Sieve 過濾伺服器",
+    "Select a S/MIME certificate for signing and encrypting" : "選擇用於簽署和加密的 S/MIME 證書",
     "Update alias" : "更新别名",
     "Show update alias form" : "顯示更新別名表格",
+    "Select S/MIME certificate" : "選擇 S/MIME 證書",
     "Delete alias" : "删除别名",
+    "{commonName} - Valid until {expiryDate}" : "{commonName} - 有效期至 {expiryDate}",
+    "Change name" : "更改名稱",
     "Email address" : "電郵地址",
     "Add alias" : "新增別名",
     "Create alias" : "創建别名",
@@ -89,6 +93,7 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "使用 Gravatar 和 favicon 虛擬化身圖示",
     "Register as application for mail links" : "註冊為處理郵件連結的應用程式",
     "Show keyboard shortcuts" : "顯示鍵盤快捷鍵",
+    "Manage S/MIME certificates" : "管理 S/MIME 證書",
     "Looking for a way to encrypt your emails?" : "正在尋找加密電子郵件的方法嗎？",
     "Install Mailvelope browser extension here" : "在此安裝 Mailvelope 瀏覽器擴充套件",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "允許應用程式蒐集關於您互動的資料。以此資料為基礎，應用程式將會適應您的偏好設定。資料將只會儲存在本機。",
@@ -106,6 +111,7 @@ OC.L10N.register(
     "Subject" : "主題",
     "Subject …" : "主題 …",
     "This message came from a noreply address so your reply will probably not be read." : "此郵件來自 noreply 地址，所以您的回覆可能不會被閱讀。",
+    "The following recipients do not have a S/MIME certificate: {recipients}." : "以下收件者沒有 S/MIME 證書：{recipients}。",
     "The following recipients do not have a PGP key: {recipients}." : "以下收件者沒有 PGP 金鑰：{recipients}。",
     "Write message …" : "編寫郵件 ...",
     "Saving draft …" : "正在儲存草稿 …",
@@ -115,10 +121,13 @@ OC.L10N.register(
     "Discard & close draft" : "丟棄並關閉草稿",
     "Upload attachment" : "已上傳附件",
     "Add attachment from Files" : "從雲端檔案中加入附件",
+    "Add link" : "加入連結",
     "Send later" : "稍後傳送",
     "Enable formatting" : "啟用格式",
     "Disable formatting" : "停用格式",
     "Request a read receipt" : "索取讀取回條",
+    "Sign message with S/MIME" : "使用 S/MIME 簽署訊息",
+    "Encrypt message with S/MIME" : "使用 S/MIME 加密訊息",
     "Encrypt message with Mailvelope" : "使用 Mailvelope 加密郵件",
     "Send now" : "立即傳送",
     "Tomorrow morning" : "明天早上",
@@ -126,22 +135,14 @@ OC.L10N.register(
     "Monday morning" : "星期一早上",
     "Custom date and time" : "自訂日期與時間",
     "Enter a date" : "輸入日期",
-    "Uploading attachments …" : "正在上傳附件……",
-    "Sending …" : "傳送中 ...",
-    "Error sending your message" : "傳送您的郵件時發生錯誤",
-    "Go back" : "返回",
-    "Retry" : "重試",
-    "Warning sending your message" : "傳送您的郵件時發生警告",
-    "Send anyway" : "仍然傳送",
-    "Message will be sent at" : "訊息將會傳送於",
-    "Message sent!" : "信件已寄出",
     "Add share link from {productName} Files" : "從 {productName} 檔案新增分享連結",
+    "Encrypt with S/MIME and send later" : "使用 S/MIME 加密並稍後傳送",
+    "Encrypt with S/MIME and send" : "使用 S/MIME 加密並傳送",
+    "Encrypt with Mailvelope and send later" : "使用 Mailvelope 加密並稍後傳送",
+    "Encrypt with Mailvelope and send" : "使用 Mailvelope 加密並傳送",
     "Send" : "傳送",
-    "Encrypt and send" : "加密並傳送",
-    "Send unencrypted" : "傳送未加密的",
     "Message {id} could not be found" : "找不到郵件 {id}",
-    "No sent mailbox configured. Please pick one in the account settings." : "未設定寄件備份信箱。請在賬號設定中選取。",
-    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "您正在嘗試發送給“收件人”和/或“抄送”中的許多收件人。考慮使用密件抄送（Bcc）隱藏收件人地址。",
+    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "已選擇使用 S/MIME 簽署或加密，但所選別名沒有證書。此郵件將不會被簽名或加密。",
     "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "任何現有格式（例如粗體、斜體、下劃線或內嵌圖像）都將被刪除。",
     "Turn off formatting" : "停用格式",
     "Turn off and remove formatting" : "停用並刪除格式",
@@ -169,7 +170,6 @@ OC.L10N.register(
     "Unselect" : "取消選擇",
     "Select" : "選擇",
     "Edit tags" : "編輯標籤",
-    "Move" : "移動",
     "Move thread" : "移動主題",
     "Archive thread" : "封存主題",
     "Delete thread" : "刪除主題",
@@ -259,6 +259,7 @@ OC.L10N.register(
     "Always show images from {domain}" : "一律顯示來自 {domain} 的圖像",
     "Message frame" : "郵件框",
     "Quoted text" : "引用文字",
+    "Move" : "移動",
     "Moving" : "正在移動",
     "Moving thread" : "移動主題",
     "Moving message" : "移動訊息",
@@ -285,6 +286,7 @@ OC.L10N.register(
     "Mark all messages of this mailbox as read" : "將此信箱所有的郵件標記為已讀",
     "Add submailbox" : "新增子信箱",
     "Edit name" : "編輯名稱",
+    "Move mailbox" : "移動信箱",
     "Clear cache" : "清除緩存",
     "Clear locally cached data, in case there are issues with synchronization." : "如果遇到同步問題，請清除近端緩存資料。",
     "Subscribed" : "已訂閱",
@@ -300,8 +302,17 @@ OC.L10N.register(
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{total} 中的 {unread} 未讀"],
     "Outbox" : "發件箱",
     "New message" : "新郵件",
+    "Error sending your message" : "傳送您的郵件時發生錯誤",
+    "Go back" : "返回",
+    "Retry" : "重試",
+    "Uploading attachments …" : "正在上傳附件……",
+    "Sending …" : "傳送中 ...",
+    "Warning sending your message" : "傳送您的郵件時發生警告",
+    "Send anyway" : "仍然傳送",
     "Edit message" : "編輯訊息",
     "Draft" : "草稿",
+    "No sent mailbox configured. Please pick one in the account settings." : "未設定寄件備份信箱。請在賬號設定中選取。",
+    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "您正在嘗試發送給“收件人”和/或“抄送”中的許多收件人。考慮使用密件抄送（Bcc）隱藏收件人地址。",
     "Message discarded" : "訊息已刪除",
     "Could not discard message" : "無法掉棄訊息",
     "No message selected" : "未選擇郵件",
@@ -309,6 +320,7 @@ OC.L10N.register(
     "Autoresponder on" : "開啟自動回復程式",
     "First day" : "第一天",
     "Last day (optional)" : "最後一天（可選）",
+    "${subject} will be replaced with the subject of the message you are responding to" : "${subject} 將替換為您要回應的郵件的主題",
     "Message" : "訊息",
     "Oh Snap!" : "哎呀！",
     "Save autoresponder" : "保存自動回復程式",
@@ -323,6 +335,8 @@ OC.L10N.register(
     "Copy to clipboard" : "複製到剪貼板",
     "Contact name …" : "聯絡人名稱 ...",
     "Add" : "新增",
+    "Copied email address to clipboard" : "將電郵地址複製到剪貼板",
+    "Could not copy email address to clipboard" : "無法將電郵地址複製到剪貼板",
     "Search in mailbox" : "在郵箱中搜尋",
     "Search parameters" : "在參數中搜尋",
     "Search term" : "搜尋字詞",
@@ -376,6 +390,9 @@ OC.L10N.register(
     "Mark as read" : "標為已讀",
     "Archive message" : "封存郵件",
     "Delete message" : "刪除訊息",
+    "This message was encrypted by the sender before it was sent." : "此訊息在發送前已由寄件人加密。",
+    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "此郵件包含經過驗證的數位 S/MIME 簽名。郵件自發送後未更改。",
+    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "此郵件包含未經驗證的數位 S/MIME 簽名。郵件可能在發送後已更改，或者簽名者的證書不受信任。",
     "Remove" : "移除",
     "No senders are trusted at the moment." : "當前沒有發件人是受信任的",
     "Could not remove trusted sender {sender}" : "無法刪除受信任的發件人 {sender}",
@@ -414,6 +431,9 @@ OC.L10N.register(
     "Gmail integration" : "Gmail 整合",
     "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail 允許用戶透過 IMAP 存取他們的電子郵件。出於安全原因，只有使用 OAuth 2.0 連接或使用雙重認證和應用程式密碼的 Google 帳戶才能進行此存取。",
     "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "您必須在 Google Cloud 控制台中為「Web 應用程式」註冊一個新的客戶端 ID。添加 URL {url} 作為授權重定向 URI。",
+    "Microsoft integration" : "Microsoft 整合",
+    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft 允許用戶通過 IMAP 存取電郵。出於安全原因，此存取只能通過 OAuth 2.0 連接進行。",
+    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "您必須在 Microsoft Azure Active Directory 中註冊一個新應用程式。然後添加 URL {url} 作為重定向 URI。",
     "Successfully updated config for \"{domain}\"" : "已成功更新 “{domain}” 的配置",
     "Error saving config" : "存儲配置時發生錯誤",
     "Saved config for \"{domain}\"" : "已成功保存 “{domain}” 的配置",
@@ -440,6 +460,11 @@ OC.L10N.register(
     "Could not configure Google integration" : "無法配置 Google 整合",
     "Google integration unlinked" : "取消 Google 整合鏈接",
     "Could not unlink Google integration" : "無法取消 Google 整合連結",
+    "Tenant ID (optional)" : "租戶 ID（非強制的）",
+    "Microsoft integration configured" : "已配置 Microsoft 整合",
+    "Could not configure Microsoft integration" : "無法配置 Microsoft 整合",
+    "Microsoft integration unlinked" : "已取消 Microsoft 整合連結",
+    "Could not unlink Microsoft integration" : "無法取消 Microsoft 整合連結",
     "Domain Match: {provisioningDomain}" : "網域匹配：{provisioningDomain}",
     "Email: {email}" : "電子郵件：{email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP：{user} 在 {host}：{port}（{ssl} 加密）",
@@ -465,8 +490,25 @@ OC.L10N.register(
     "Unprovision & Delete Config" : "取消配置和刪除配置",
     "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% 與 %EMAIL% 將以用戶的 UID 與電郵地址取代",
     "With the settings above, the app will create account settings in the following way:" : "使用上述設定，應用程式將會以下列方式建立賬號：",
-    "Account connected" : "賬戶已連結",
-    "You can close this window" : "可以關閉此視窗",
+    "S/MIME certificates" : "S/MIME 證書",
+    "Certificate name" : "證書名稱",
+    "E-mail address" : "電郵地址",
+    "Valid until" : "到期日",
+    "Delete certificate" : "刪除憑證",
+    "Import certificate" : "導入證書",
+    "Import S/MIME certificate" : "導入 S/MIME 證書",
+    "PKCS #12 Certificate" : "PKCS #12 證書",
+    "PEM Certificate" : "PEM 證書",
+    "Certificate" : "憑證",
+    "Private key (optional)" : "私鑰（非強制的）",
+    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "僅當您打算使用此證書發送簽名和加密的電子郵件時才需要私鑰。",
+    "Back" : "返回",
+    "Submit" : "遞交",
+    "The provided PKCS #12 certificate must contain a single certificate and private key." : "提供的 PKCS #12 證書必須包含單個證書和私鑰。",
+    "Failed to import the certificate. Please check the password." : "無法導入證書。請檢查密碼。",
+    "Certificate imported successfully" : "成功導入了證書",
+    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "無法導入證書。請確保私鑰與證書匹配並且不受密碼片語保護。",
+    "Failed to import the certificate" : "導入證書失敗",
     "Keyboard shortcut" : "鍵盤快捷鍵",
     "Keyboard shortcuts" : "鍵盤快捷鍵",
     "Speed up your Mail experience with these quick shortcuts." : "這些鍵盤快捷鍵可加快您的郵件使用體驗。",
@@ -475,12 +517,14 @@ OC.L10N.register(
     "Older message" : "較舊的信件",
     "Toggle star" : "加上／移除星號",
     "Toggle unread" : "標示未讀／已讀",
+    "Archive" : "封存",
     "Refresh" : "重新整理",
+    "Account connected" : "賬戶已連結",
+    "You can close this window" : "可以關閉此視窗",
     "Connect your mail account" : "連結您的郵件賬號",
     "To add a mail account, please contact your administrator." : "要添加電郵帳戶，請聯繫您的管理員。",
     "Itinerary for {type} is not supported yet" : "目前尚未支援 {type} 的行程",
     "All" : "全部",
-    "Archive" : "封存",
     "Drafts" : "草稿",
     "Favorites" : "我的最愛",
     "Priority inbox" : "優先收件匣",
@@ -489,6 +533,7 @@ OC.L10N.register(
     "Junk" : "垃圾郵件",
     "Sent" : "發送",
     "Trash" : "回收桶",
+    "Connect OAUTH2 account" : "連接 OAUTH2 賬戶",
     "Error while sharing file" : "分享檔案時發生錯誤",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n 則新信件\n來自 {from}"],
