@@ -49,6 +49,7 @@ OC.L10N.register(
     "Looking up configuration" : "正在查詢設定",
     "Checking mail host connectivity" : "正在檢查郵件主機連線能力",
     "Configuration discovery failed. Please use the manual settings" : "設定探索失敗。請使用手動設定",
+    "Password required" : "請輸入密碼",
     "Testing authentication" : "正在測試驗證",
     "Awaiting user consent" : "等待使用者同意",
     "Account created. Please follow the popup instructions to link your Google account" : "帳號已建立。請按照彈出的說明連結您的 Google 帳號",
@@ -61,10 +62,9 @@ OC.L10N.register(
     "SMTP username or password is wrong" : "SMTP 使用者名稱或密碼錯誤",
     "IMAP connection failed" : "IMAP 連線失敗",
     "SMTP connection failed" : "SMTP 連線失敗",
-    "Google authorization popup closed" : "Google 授權彈出式視窗已關閉",
+    "Authorization pop-up closed" : "已關閉授權彈出式視窗",
     "There was an error while setting up your account" : "設定您的帳號時發生錯誤",
     "Account settings" : "帳號設定",
-    "Change name" : "更改名稱",
     "Signature" : "簽章",
     "A signature is added to the text of new messages and replies." : "對新信件與回覆信件內容已新增一個簽名檔",
     "Writing mode" : "寫作模式",
@@ -78,9 +78,13 @@ OC.L10N.register(
     "Trusted senders" : "信任的寄件者",
     "Mail server" : "郵件伺服器",
     "Sieve filter server" : "過濾伺服器",
+    "Select a S/MIME certificate for signing and encrypting" : "選取用來簽署與加密的 S/MIME 憑證",
     "Update alias" : "更新别名",
     "Show update alias form" : "顯示更新別名表格",
+    "Select S/MIME certificate" : "選取 S/MIME 憑證",
     "Delete alias" : "删除别名",
+    "{commonName} - Valid until {expiryDate}" : "{commonName} - 有效期限至 {expiryDate}",
+    "Change name" : "更改名稱",
     "Email address" : "電子郵件地址",
     "Add alias" : "新增別名",
     "Create alias" : "建立別名",
@@ -89,6 +93,7 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "使用個人化大頭貼與網站圖示",
     "Register as application for mail links" : "註冊為郵件連結的處理應用程式",
     "Show keyboard shortcuts" : "顯示鍵盤快捷鍵",
+    "Manage S/MIME certificates" : "管理 S/MIME 憑證",
     "Looking for a way to encrypt your emails?" : "正在尋找加密您的電子郵件的方法？",
     "Install Mailvelope browser extension here" : "在此安裝 Mailvelope 瀏覽器擴充套件",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "允許應用程式蒐集關於您互動的資料。以此資料為基礎，應用程式將會適應您的偏好設定。資料將只會儲存在本機。",
@@ -106,6 +111,7 @@ OC.L10N.register(
     "Subject" : "主旨",
     "Subject …" : "主旨……",
     "This message came from a noreply address so your reply will probably not be read." : "此郵件來自 noreply 地址，所以您的回覆可能不會被閱讀。",
+    "The following recipients do not have a S/MIME certificate: {recipients}." : "以下收件者沒有 S/MIME 憑證：{recipients}。",
     "The following recipients do not have a PGP key: {recipients}." : "以下收件者沒有 PGP 金鑰：{recipients}。",
     "Write message …" : "編寫郵件……",
     "Saving draft …" : "正在儲存草稿……",
@@ -115,10 +121,13 @@ OC.L10N.register(
     "Discard & close draft" : "放棄並關閉草稿",
     "Upload attachment" : "已上傳附件",
     "Add attachment from Files" : "從雲端檔案中加入附件",
+    "Add link" : "新增連結",
     "Send later" : "稍後傳送",
     "Enable formatting" : "啟用格式",
     "Disable formatting" : "停用格式化",
     "Request a read receipt" : "索取讀取回條",
+    "Sign message with S/MIME" : "使用 S/MIME 簽署訊息",
+    "Encrypt message with S/MIME" : "使用 S/MIME 加密訊息",
     "Encrypt message with Mailvelope" : "使用 Mailvelope 加密郵件",
     "Send now" : "立刻傳送",
     "Tomorrow morning" : "明天早上",
@@ -126,22 +135,14 @@ OC.L10N.register(
     "Monday morning" : "週一早上",
     "Custom date and time" : "自訂日期與時間",
     "Enter a date" : "輸入日期",
-    "Uploading attachments …" : "正在上傳附件……",
-    "Sending …" : "正在傳送……",
-    "Error sending your message" : "傳送您的郵件時發生錯誤",
-    "Go back" : "返回",
-    "Retry" : "重試",
-    "Warning sending your message" : "在傳送您的郵件時警告",
-    "Send anyway" : "無論無何都要傳送",
-    "Message will be sent at" : "郵件將傳送至",
-    "Message sent!" : "信件已寄出",
     "Add share link from {productName} Files" : "從 {productName} 檔案新增分享連結",
+    "Encrypt with S/MIME and send later" : "使用 S/MIME 加密並稍後傳送",
+    "Encrypt with S/MIME and send" : "使用 S/MIME 加密並傳送",
+    "Encrypt with Mailvelope and send later" : "使用 Mailvelope 加密並稍後傳送",
+    "Encrypt with Mailvelope and send" : "使用 Mailvelope 加密並傳送",
     "Send" : "傳送",
-    "Encrypt and send" : "加密並傳送",
-    "Send unencrypted" : "傳送未加密的",
     "Message {id} could not be found" : "找不到郵件 {id}",
-    "No sent mailbox configured. Please pick one in the account settings." : "未設定寄件備份信箱。請在帳號設定中選取。",
-    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "您正試圖傳送郵件給「收件者」及／或「副本」中的許多人。請考慮使用「密件副本」來隱藏收件者地址。",
+    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "已選取使用 S/MIME 簽署或加密，但選定的別名沒有憑證。此訊息將不會被簽署或加密。",
     "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "任何現有格式（例如粗體、義式斜體、底線或內嵌圖片）都將被移除。",
     "Turn off formatting" : "關閉格式化",
     "Turn off and remove formatting" : "關閉並移除格式化",
@@ -169,7 +170,6 @@ OC.L10N.register(
     "Unselect" : "取消選取",
     "Select" : "選取",
     "Edit tags" : "編輯標籤",
-    "Move" : "移動",
     "Move thread" : "移動討論串",
     "Archive thread" : "封存討論串",
     "Delete thread" : "刪除討論串",
@@ -259,6 +259,7 @@ OC.L10N.register(
     "Always show images from {domain}" : "一律顯示來自 {domain} 的圖片",
     "Message frame" : "郵件框",
     "Quoted text" : "引用文字",
+    "Move" : "移動",
     "Moving" : "正在移動",
     "Moving thread" : "正在移動討論串",
     "Moving message" : "正在移動訊息",
@@ -285,6 +286,7 @@ OC.L10N.register(
     "Mark all messages of this mailbox as read" : "將此信箱所有的郵件標記為已讀",
     "Add submailbox" : "新增子信箱",
     "Edit name" : "編輯名稱",
+    "Move mailbox" : "移動信箱",
     "Clear cache" : "清除快取",
     "Clear locally cached data, in case there are issues with synchronization." : "如果遇到同步問題，請清除本機快取資料。",
     "Subscribed" : "已訂閱",
@@ -300,8 +302,17 @@ OC.L10N.register(
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{total} 中的 {unread} 未讀"],
     "Outbox" : "寄件匣",
     "New message" : "新郵件",
+    "Error sending your message" : "傳送您的郵件時發生錯誤",
+    "Go back" : "返回",
+    "Retry" : "重試",
+    "Uploading attachments …" : "正在上傳附件……",
+    "Sending …" : "正在傳送……",
+    "Warning sending your message" : "在傳送您的郵件時警告",
+    "Send anyway" : "無論無何都要傳送",
     "Edit message" : "編輯訊息",
     "Draft" : "草稿",
+    "No sent mailbox configured. Please pick one in the account settings." : "未設定寄件備份信箱。請在帳號設定中選取。",
+    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "您正試圖傳送郵件給「收件者」及／或「副本」中的許多人。請考慮使用「密件副本」來隱藏收件者地址。",
     "Message discarded" : "郵件已捨棄",
     "Could not discard message" : "無法捨棄郵件",
     "No message selected" : "未選取郵件",
@@ -309,6 +320,7 @@ OC.L10N.register(
     "Autoresponder on" : "自動回覆程式啟用",
     "First day" : "第一天",
     "Last day (optional)" : "最後一天（選擇性）",
+    "${subject} will be replaced with the subject of the message you are responding to" : "${subject} 將替換為您要回應的郵件的主旨",
     "Message" : "訊息",
     "Oh Snap!" : "喔喔！",
     "Save autoresponder" : "儲存自動回覆程式",
@@ -323,6 +335,8 @@ OC.L10N.register(
     "Copy to clipboard" : "複製到剪貼簿",
     "Contact name …" : "聯絡人名稱……",
     "Add" : "新增",
+    "Copied email address to clipboard" : "將電子郵件地址複製到剪貼簿",
+    "Could not copy email address to clipboard" : "無法複製電子郵件地址到剪貼簿",
     "Search in mailbox" : "在郵件匣中搜尋",
     "Search parameters" : "搜尋參數",
     "Search term" : "搜尋字詞",
@@ -376,6 +390,9 @@ OC.L10N.register(
     "Mark as read" : "標為已讀",
     "Archive message" : "封存訊息",
     "Delete message" : "刪除訊息",
+    "This message was encrypted by the sender before it was sent." : "此訊息在傳送前已由寄件人加密。",
+    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "此訊息包含了已驗證的數位 S/MIME 簽章。訊息自傳送後未變更。",
+    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "此訊息包含了未驗證的 S/MIME 簽章。訊息在傳送後可能已被變更，或是簽章者的證書不受信任。",
     "Remove" : "移除",
     "No senders are trusted at the moment." : "目前沒有寄件者受到信任。",
     "Could not remove trusted sender {sender}" : "無法移除受信任的寄件者 {sender}",
@@ -414,6 +431,9 @@ OC.L10N.register(
     "Gmail integration" : "Gmail 整合",
     "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail 讓使用者可以透過 IMAP 存取他們的電子郵件。出於安全理由，僅能使用 OAuth 2.0 連線或使用雙重驗證與應用程式密碼的 Google 帳號才能進行此存取。",
     "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "您必須在 Google Cloud 主控台中的「Web 應用程式」註冊一個新的客戶端 ID。新增 URL {url} 作為授權重新導向 URI。",
+    "Microsoft integration" : "Microsoft 整合",
+    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft 允許使用者透過 IMAP 存取電子郵件。出於安全性的原因，此存取只能透過 OAuth 2.0 連線進行。",
+    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "您必須在 Microsoft Azure Active Directory 入口網站中註冊一個新應用程式。然後新增 URL {url} 作為重新導向 URI。",
     "Successfully updated config for \"{domain}\"" : "成功為「{domain}」更新設定",
     "Error saving config" : "儲存設定時發生錯誤",
     "Saved config for \"{domain}\"" : "已為「{domain}」儲存設定",
@@ -440,6 +460,11 @@ OC.L10N.register(
     "Could not configure Google integration" : "無法設定 Google 整合",
     "Google integration unlinked" : "Google 整合已取消連結",
     "Could not unlink Google integration" : "無法取消連結 Google 整合",
+    "Tenant ID (optional)" : "租戶 ID（選擇性）",
+    "Microsoft integration configured" : "已設定 Microsoft 整合",
+    "Could not configure Microsoft integration" : "無法設定 Microsoft 整合",
+    "Microsoft integration unlinked" : "取消連結 Microsoft 整合",
+    "Could not unlink Microsoft integration" : "無法取消連結 Microsoft 整合",
     "Domain Match: {provisioningDomain}" : "網域符合：{provisioningDomain}",
     "Email: {email}" : "電子郵件：{email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP：{user} 在 {host}:{port}（{ssl} 加密）",
@@ -465,8 +490,25 @@ OC.L10N.register(
     "Unprovision & Delete Config" : "取消設定與刪除設定",
     "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% 與 %EMAIL% 將以使用者的 UID 與電子郵件取代",
     "With the settings above, the app will create account settings in the following way:" : "使用上述設定，應用程式將會以下列方式建立帳號：",
-    "Account connected" : "已連結帳號",
-    "You can close this window" : "您可以關閉此視窗",
+    "S/MIME certificates" : "S/MIME 憑證",
+    "Certificate name" : "憑證名稱",
+    "E-mail address" : "電子郵件地址",
+    "Valid until" : "到期日",
+    "Delete certificate" : "刪除憑證",
+    "Import certificate" : "匯入憑證",
+    "Import S/MIME certificate" : "匯入 S/MIME 憑證",
+    "PKCS #12 Certificate" : "PKCS #12 憑證",
+    "PEM Certificate" : "PEM 憑證",
+    "Certificate" : "憑證",
+    "Private key (optional)" : "私鑰（選擇性）",
+    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "僅當您打算使用此憑證傳送簽署與加密的電子郵件時才需要私鑰。",
+    "Back" : "返回",
+    "Submit" : "遞交",
+    "The provided PKCS #12 certificate must contain a single certificate and private key." : "提供的 PKCS #12 憑證必須包含單一個憑證與私鑰。",
+    "Failed to import the certificate. Please check the password." : "匯入憑證失敗。請檢查密碼。",
+    "Certificate imported successfully" : "成功匯出憑證",
+    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "無法匯入憑證。請確保私鑰與憑證相符，且不受密語保護。",
+    "Failed to import the certificate" : "匯入憑證失敗",
     "Keyboard shortcut" : "鍵盤快捷鍵",
     "Keyboard shortcuts" : "鍵盤快捷鍵",
     "Speed up your Mail experience with these quick shortcuts." : "這些鍵盤快捷鍵可加快您的郵件使用體驗。",
@@ -475,12 +517,14 @@ OC.L10N.register(
     "Older message" : "較舊的信件",
     "Toggle star" : "加上／移除星號",
     "Toggle unread" : "標示未讀／已讀",
+    "Archive" : "封存",
     "Refresh" : "重新整理",
+    "Account connected" : "已連結帳號",
+    "You can close this window" : "您可以關閉此視窗",
     "Connect your mail account" : "連結您的郵件帳號",
     "To add a mail account, please contact your administrator." : "要新增郵件帳號，請聯絡您的管理員。",
     "Itinerary for {type} is not supported yet" : "目前尚未支援 {type} 的行程",
     "All" : "全部",
-    "Archive" : "封存",
     "Drafts" : "草稿",
     "Favorites" : "我的最愛",
     "Priority inbox" : "優先收件匣",
@@ -489,6 +533,7 @@ OC.L10N.register(
     "Junk" : "垃圾郵件",
     "Sent" : "寄件備份",
     "Trash" : "回收筒",
+    "Connect OAUTH2 account" : "連結 OAUTH2 帳號",
     "Error while sharing file" : "分享檔案時發生錯誤",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n 則新信件\n來自 {from}"],
