@@ -10,6 +10,7 @@ declare(strict_types=1);
  * @author Robin McCorkell <rmccorkell@karoshi.org.uk>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Matthias Rella <mrella@pisys.eu>
+ * @author Richard Steinmetz <richard@steinmetz.cloud>
  *
  * Mail
  *
@@ -29,6 +30,7 @@ declare(strict_types=1);
 
 namespace OCA\Mail\Controller;
 
+use OCA\Mail\Http\TrapError;
 use Horde_Imap_Client;
 use OCA\Mail\AppInfo\Application;
 use OCA\Mail\Contracts\IMailManager;
@@ -44,6 +46,7 @@ use OCA\Mail\Service\AliasesService;
 use OCA\Mail\Service\SetupService;
 use OCA\Mail\Service\Sync\SyncService;
 use OCA\Mail\Validation\RemoteHostValidator;
+use OCA\Mail\IMAP\MailboxSync;
 use OCP\AppFramework\Controller;
 use OCP\AppFramework\Http;
 use OCP\AppFramework\Http\JSONResponse;
@@ -64,6 +67,7 @@ class AccountsController extends Controller {
 	private SyncService $syncService;
 	private IConfig $config;
 	private RemoteHostValidator $hostValidator;
+	private MailboxSync $mailboxSync;
 
 	public function __construct(string $appName,
 								   IRequest $request,
@@ -77,7 +81,8 @@ class AccountsController extends Controller {
 								   IMailManager $mailManager,
 								   SyncService $syncService,
 									IConfig $config,
-									RemoteHostValidator $hostValidator
+									RemoteHostValidator $hostValidator,
+									MailboxSync $mailboxSync
 	) {
 		parent::__construct($appName, $request);
 		$this->accountService = $accountService;
@@ -91,14 +96,15 @@ class AccountsController extends Controller {
 		$this->syncService = $syncService;
 		$this->config = $config;
 		$this->hostValidator = $hostValidator;
+		$this->mailboxSync = $mailboxSync;
 	}
 
 	/**
 	 * @NoAdminRequired
-	 * @TrapError
 	 *
 	 * @return JSONResponse
 	 */
+	#[TrapError]
 	public function index(): JSONResponse {
 		$mailAccounts = $this->accountService->findByUserId($this->currentUserId);
 
@@ -113,20 +119,19 @@ class AccountsController extends Controller {
 
 	/**
 	 * @NoAdminRequired
-	 * @TrapError
 	 *
 	 * @param int $id
 	 *
 	 * @return JSONResponse
 	 * @throws ClientException
 	 */
+	#[TrapError]
 	public function show(int $id): JSONResponse {
 		return new JSONResponse($this->accountService->find($this->currentUserId, $id));
 	}
 
 	/**
 	 * @NoAdminRequired
-	 * @TrapError
 	 *
 	 * @param int $id
 	 * @param string $accountName
@@ -146,6 +151,7 @@ class AccountsController extends Controller {
 	 * @return JSONResponse
 	 * @throws ClientException
 	 */
+	#[TrapError]
 	public function update(int $id,
 						   string $accountName,
 						   string $emailAddress,
@@ -211,7 +217,6 @@ class AccountsController extends Controller {
 
 	/**
 	 * @NoAdminRequired
-	 * @TrapError
 	 *
 	 * @param int $id
 	 * @param string|null $editorMode
@@ -227,6 +232,7 @@ class AccountsController extends Controller {
 	 *
 	 * @throws ClientException
 	 */
+	#[TrapError]
 	public function patchAccount(int $id,
 								 string $editorMode = null,
 								 int $order = null,
@@ -275,7 +281,6 @@ class AccountsController extends Controller {
 
 	/**
 	 * @NoAdminRequired
-	 * @TrapError
 	 *
 	 * @param int $id
 	 * @param string|null $signature
@@ -285,6 +290,7 @@ class AccountsController extends Controller {
 	 * @throws ClientException
 	 * @throws ServiceException
 	 */
+	#[TrapError]
 	public function updateSignature(int $id, string $signature = null): JSONResponse {
 		$this->accountService->updateSignature($id, $this->currentUserId, $signature);
 		return new JSONResponse();
@@ -292,7 +298,6 @@ class AccountsController extends Controller {
 
 	/**
 	 * @NoAdminRequired
-	 * @TrapError
 	 *
 	 * @param int $id
 	 *
@@ -300,6 +305,7 @@ class AccountsController extends Controller {
 	 *
 	 * @throws ClientException
 	 */
+	#[TrapError]
 	public function destroy(int $id): JSONResponse {
 		$this->accountService->delete($this->currentUserId, $id);
 		return new JSONResponse();
@@ -307,7 +313,6 @@ class AccountsController extends Controller {
 
 	/**
 	 * @NoAdminRequired
-	 * @TrapError
 	 *
 	 * @param string $accountName
 	 * @param string $emailAddress
@@ -325,6 +330,7 @@ class AccountsController extends Controller {
 	 *
 	 * @return JSONResponse
 	 */
+	#[TrapError]
 	public function create(string $accountName,
 		string $emailAddress,
 		string $imapHost = null,
@@ -363,9 +369,7 @@ class AccountsController extends Controller {
 			);
 		}
 		try {
-			return MailJsonResponse::success(
-				$this->setup->createNewAccount($accountName, $emailAddress, $imapHost, $imapPort, $imapSslMode, $imapUser, $imapPassword, $smtpHost, $smtpPort, $smtpSslMode, $smtpUser, $smtpPassword, $this->currentUserId, $authMethod), Http::STATUS_CREATED
-			);
+			$account = $this->setup->createNewAccount($accountName, $emailAddress, $imapHost, $imapPort, $imapSslMode, $imapUser, $imapPassword, $smtpHost, $smtpPort, $smtpSslMode, $smtpUser, $smtpPassword, $this->currentUserId, $authMethod);
 		} catch (CouldNotConnectException $e) {
 			$data = [
 				'error' => $e->getReason(),
@@ -382,11 +386,20 @@ class AccountsController extends Controller {
 			]);
 			return MailJsonResponse::error('Could not create account');
 		}
+		try {
+			$this->mailboxSync->sync($account, $this->logger);
+		} catch (ServiceException $e) {
+			$this->logger->error('Failed syncing the newly created account' . $e->getMessage(), [
+				'exception' => $e,
+			]);
+		}
+		return MailJsonResponse::success(
+			$account, Http::STATUS_CREATED
+		);
 	}
 
 	/**
 	 * @NoAdminRequired
-	 * @TrapError
 	 *
 	 * @param int $id
 	 * @param string $subject
@@ -400,6 +413,7 @@ class AccountsController extends Controller {
 	 *
 	 * @throws ClientException
 	 */
+	#[TrapError]
 	public function draft(int $id,
 						  string $subject,
 						  string $body,
@@ -461,4 +475,20 @@ class AccountsController extends Controller {
 		}
 		return MailJsonResponse::success($quota)->cacheFor(5 * 60, false, true);
 	}
+
+	/**
+	 * @NoAdminRequired
+	 *
+	 * @param int $id Account id
+	 * @param ?int $smimeCertificateId
+	 * @return JSONResponse
+	 *
+	 * @throws ClientException
+	 */
+	public function updateSmimeCertificate(int $id, ?int $smimeCertificateId = null) {
+		$account = $this->accountService->find($this->currentUserId, $id)->getMailAccount();
+		$account->setSmimeCertificateId($smimeCertificateId);
+		$this->accountService->update($account);
+		return MailJsonResponse::success();
+	}
 }
