@@ -4,6 +4,7 @@ declare(strict_types=1);
 
 /**
  * @author Christoph Wurst <christoph@winzerhof-wurst.at>
+ * @author Richard Steinmetz <richard@steinmetz.cloud>
  *
  * Mail
  *
@@ -36,7 +37,6 @@ use function array_chunk;
 use function array_merge;
 
 class Synchronizer {
-
 	/**
 	 * This determines how many UIDs we send to IMAP for a check of changed or
 	 * vanished messages. The number needs a balance between good performance
@@ -66,6 +66,7 @@ class Synchronizer {
 	 */
 	public function sync(Horde_Imap_Client_Base $imapClient,
 						 Request $request,
+						 string $userId,
 						 int $criteria = Horde_Imap_Client::SYNC_NEWMSGSUIDS | Horde_Imap_Client::SYNC_FLAGSUIDS | Horde_Imap_Client::SYNC_VANISHEDUIDS): Response {
 		$mailbox = new Horde_Imap_Client_Mailbox($request->getMailbox());
 		try {
@@ -96,8 +97,8 @@ class Synchronizer {
 			throw $e;
 		}
 
-		$newMessages = $this->messageMapper->findByIds($imapClient, $request->getMailbox(), new Horde_Imap_Client_Ids($newUids));
-		$changedMessages = $this->messageMapper->findByIds($imapClient, $request->getMailbox(), new Horde_Imap_Client_Ids($changedUids));
+		$newMessages = $this->messageMapper->findByIds($imapClient, $request->getMailbox(), new Horde_Imap_Client_Ids($newUids), $userId);
+		$changedMessages = $this->messageMapper->findByIds($imapClient, $request->getMailbox(), new Horde_Imap_Client_Ids($changedUids), $userId);
 		$vanishedMessageUids = $vanishedUids;
 
 		return new Response($newMessages, $changedMessages, $vanishedMessageUids);
@@ -138,7 +139,7 @@ class Synchronizer {
 		return array_merge(
 			[], // for php<7.4 https://www.php.net/manual/en/function.array-merge.php
 			...array_map(
-				function (array $uids) use ($imapClient, $mailbox, $request) {
+				static function (array $uids) use ($imapClient, $mailbox, $request) {
 					return $imapClient->sync($mailbox, $request->getToken(), [
 						'criteria' => Horde_Imap_Client::SYNC_FLAGSUIDS,
 						'ids' => new Horde_Imap_Client_Ids($uids),
@@ -168,7 +169,7 @@ class Synchronizer {
 		$vanishedUids = array_merge(
 			[], // for php<7.4 https://www.php.net/manual/en/function.array-merge.php
 			...array_map(
-				function (array $uids) use ($imapClient, $mailbox, $request) {
+				static function (array $uids) use ($imapClient, $mailbox, $request) {
 					return $imapClient->sync($mailbox, $request->getToken(), [
 						'criteria' => Horde_Imap_Client::SYNC_VANISHEDUIDS,
 						'ids' => new Horde_Imap_Client_Ids($uids),
