@@ -4,6 +4,7 @@ declare(strict_types=1);
 
 /**
  * @author Christoph Wurst <christoph@winzerhof-wurst.at>
+ * @author Richard Steinmetz <richard@steinmetz.cloud>
  *
  * Mail
  *
@@ -28,7 +29,9 @@ use Horde_Imap_Client_Exception;
 use Horde_Imap_Client_Exception_NoSupportExtension;
 use Horde_Imap_Client_Ids;
 use Horde_Imap_Client_Socket;
+use Horde_Mime_Exception;
 use OCA\Mail\Account;
+use OCA\Mail\Attachment;
 use OCA\Mail\Contracts\IMailManager;
 use OCA\Mail\Db\Mailbox;
 use OCA\Mail\Db\MailboxMapper;
@@ -156,9 +159,8 @@ class MailManager implements IMailManager {
 			$this->folderMapper->getFoldersStatus([$folder], $client);
 		} catch (Horde_Imap_Client_Exception $e) {
 			throw new ServiceException(
-				"Could not get mailbox status: " .
-				$e->getMessage(),
-				(int)$e->getCode(),
+				"Could not get mailbox status: " . $e->getMessage(),
+				$e->getCode(),
 				$e
 			);
 		} finally {
@@ -171,26 +173,36 @@ class MailManager implements IMailManager {
 		return $this->mailboxMapper->find($account, $name);
 	}
 
-	public function getImapMessage(Account $account,
+	/**
+	 * @param Horde_Imap_Client_Socket $client
+	 * @param Account $account
+	 * @param Mailbox $mailbox
+	 * @param int $uid
+	 * @param bool $loadBody
+	 *
+	 * @return IMAPMessage
+	 *
+	 * @throws ServiceException
+	 */
+	public function getImapMessage(Horde_Imap_Client_Socket $client,
+								   Account $account,
 								   Mailbox $mailbox,
 								   int $uid,
 								   bool $loadBody = false): IMAPMessage {
-		$client = $this->imapClientFactory->getClient($account);
 		try {
 			return $this->imapMessageMapper->find(
 				$client,
 				$mailbox->getName(),
 				$uid,
+				$account->getUserId(),
 				$loadBody
 			);
 		} catch (Horde_Imap_Client_Exception | DoesNotExistException $e) {
 			throw new ServiceException(
 				"Could not load message",
-				(int)$e->getCode(),
+				$e->getCode(),
 				$e
 			);
-		} finally {
-			$client->logout();
 		}
 	}
 
@@ -210,12 +222,13 @@ class MailManager implements IMailManager {
 				$client,
 				$mailbox->getName(),
 				new Horde_Imap_Client_Ids($uids),
+				$account->getUserId(),
 				true
 			);
 		} catch (Horde_Imap_Client_Exception $e) {
 			throw new ServiceException(
 				'Could not load messages: ' . $e->getMessage(),
-				(int)$e->getCode(),
+				$e->getCode(),
 				$e
 			);
 		} finally {
@@ -236,27 +249,29 @@ class MailManager implements IMailManager {
 	}
 
 	/**
+	 * @param Horde_Imap_Client_Socket $client
 	 * @param Account $account
 	 * @param string $mailbox
 	 * @param int $uid
 	 *
 	 * @return string
 	 *
-	 * @throws ClientException
 	 * @throws ServiceException
 	 */
-	public function getSource(Account $account, string $mailbox, int $uid): ?string {
-		$client = $this->imapClientFactory->getClient($account);
+	public function getSource(Horde_Imap_Client_Socket $client,
+							  Account $account,
+							  string $mailbox,
+							  int $uid): ?string {
 		try {
 			return $this->imapMessageMapper->getFullText(
 				$client,
 				$mailbox,
-				$uid
+				$uid,
+				$account->getUserId(),
+				false,
 			);
 		} catch (Horde_Imap_Client_Exception | DoesNotExistException $e) {
 			throw new ServiceException("Could not load message", 0, $e);
-		} finally {
-			$client->logout();
 		}
 	}
 
@@ -396,7 +411,7 @@ class MailManager implements IMailManager {
 		} catch (Horde_Imap_Client_Exception $e) {
 			throw new ServiceException(
 				"Could not set subscription status for mailbox " . $mailbox->getId() . " on IMAP: " . $e->getMessage(),
-				(int)$e->getCode(),
+				$e->getCode(),
 				$e
 			);
 		} finally {
@@ -445,7 +460,7 @@ class MailManager implements IMailManager {
 		} catch (Horde_Imap_Client_Exception $e) {
 			throw new ServiceException(
 				"Could not set message flag on IMAP: " . $e->getMessage(),
-				(int)$e->getCode(),
+				$e->getCode(),
 				$e
 			);
 		} finally {
@@ -498,7 +513,7 @@ class MailManager implements IMailManager {
 			} catch (Horde_Imap_Client_Exception $e) {
 				throw new ServiceException(
 					"Could not set message keyword on IMAP: " . $e->getMessage(),
-					(int)$e->getCode(),
+					$e->getCode(),
 					$e
 				);
 			} finally {
@@ -543,7 +558,7 @@ class MailManager implements IMailManager {
 		 *
 		 * @see https://tools.ietf.org/html/rfc2087#section-3
 		 */
-		$storageQuotas = array_map(function (array $root) {
+		$storageQuotas = array_map(static function (array $root) {
 			return $root['storage'] ?? [
 				'usage' => 0,
 				'limit' => 0,
@@ -650,12 +665,48 @@ class MailManager implements IMailManager {
 	 * @param Account $account
 	 * @param Mailbox $mailbox
 	 * @param Message $message
-	 * @return array[]
+	 * @return Attachment[]
 	 */
 	public function getMailAttachments(Account $account, Mailbox $mailbox, Message $message): array {
 		$client = $this->imapClientFactory->getClient($account);
 		try {
-			return $this->imapMessageMapper->getAttachments($client, $mailbox->getName(), $message->getUid());
+			return $this->imapMessageMapper->getAttachments(
+				$client,
+				$mailbox->getName(),
+				$message->getUid(),
+				$account->getUserId(),
+			);
+		} finally {
+			$client->logout();
+		}
+	}
+
+	/**
+	 * @param Account $account
+	 * @param Mailbox $mailbox
+	 * @param Message $message
+	 * @param string $attachmentId
+	 * @return Attachment
+	 *
+	 * @throws DoesNotExistException
+	 * @throws Horde_Imap_Client_Exception
+	 * @throws Horde_Imap_Client_Exception_NoSupportExtension
+	 * @throws ServiceException
+	 * @throws Horde_Mime_Exception
+	 */
+	public function getMailAttachment(Account $account,
+									  Mailbox $mailbox,
+									  Message $message,
+									  string $attachmentId): Attachment {
+		$client = $this->imapClientFactory->getClient($account);
+		try {
+			return $this->imapMessageMapper->getAttachment(
+				$client,
+				$mailbox->getName(),
+				$message->getUid(),
+				$attachmentId,
+				$account->getUserId(),
+			);
 		} finally {
 			$client->logout();
 		}
@@ -709,7 +760,7 @@ class MailManager implements IMailManager {
 		} catch (Horde_Imap_Client_Exception $e) {
 			throw new ServiceException(
 				"Could not get message flag options from IMAP: " . $e->getMessage(),
-				(int)$e->getCode(),
+				$e->getCode(),
 				$e
 			);
 		}
